#
# PySNMP MIB module T11-FC-RSCN-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/T11-FC-RSCN-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:30:30 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion, ConstraintsIntersection, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ConstraintsIntersection", "ValueSizeConstraint")
( FcAddressIdOrZero, fcmInstanceIndex, fcmSwitchIndex, FcNameIdOrZero, ) = mibBuilder.importSymbols("FC-MGMT-MIB", "FcAddressIdOrZero", "fcmInstanceIndex", "fcmSwitchIndex", "FcNameIdOrZero")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( Counter64, mib_2, Bits, TimeTicks, NotificationType, ModuleIdentity, Unsigned32, Gauge32, Integer32, Counter32, IpAddress, iso, MibScalar, MibTable, MibTableRow, MibTableColumn, MibIdentifier, ObjectIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter64", "mib-2", "Bits", "TimeTicks", "NotificationType", "ModuleIdentity", "Unsigned32", "Gauge32", "Integer32", "Counter32", "IpAddress", "iso", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "MibIdentifier", "ObjectIdentity")
( DisplayString, TruthValue, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TruthValue", "TextualConvention")
( T11NsGs4RejectReasonCode, ) = mibBuilder.importSymbols("T11-FC-NAME-SERVER-MIB", "T11NsGs4RejectReasonCode")
( T11FabricIndex, ) = mibBuilder.importSymbols("T11-TC-MIB", "T11FabricIndex")
t11FcRscnMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 161)).setRevisions(("2007-01-08 00:00",))
if mibBuilder.loadTexts: t11FcRscnMIB.setLastUpdated('200701080000Z')
if mibBuilder.loadTexts: t11FcRscnMIB.setOrganization("For the initial versions, T11.\n                  For later versions, the IETF's IMSS Working Group.")
if mibBuilder.loadTexts: t11FcRscnMIB.setContactInfo('     Claudio DeSanti\n                  Cisco Systems, Inc.\n                  170 West Tasman Drive\n                  San Jose, CA 95134 USA\n                  EMail: cds@cisco.com\n\n                  Keith McCloghrie\n                  Cisco Systems, Inc.\n                  170 West Tasman Drive\n                  San Jose, CA 95134 USA\n                  EMail: kzm@cisco.com')
if mibBuilder.loadTexts: t11FcRscnMIB.setDescription('The MIB module for the management of registrations\n\n\n\n           by Nx_Ports to receive RSCNs (Registered State Change\n           Notifications) on a Fibre Channel Fabric, as defined\n           in FC-LS, and for the monitoring of RSCNs sent/received\n           or rejected in a Fibre Channel Fabric.\n\n           Copyright (C) The Internet Society (2007).  This version of\n           this MIB module is part of RFC 4983;  see the RFC itself for\n           full legal notices.')
t11FcRscnNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 161, 0))
t11FcRscnObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 161, 1))
t11FcRscnConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 161, 2))
t11FcRscnRegistrations = MibIdentifier((1, 3, 6, 1, 2, 1, 161, 1, 1))
t11FcRscnStats = MibIdentifier((1, 3, 6, 1, 2, 1, 161, 1, 2))
t11FcRscnInformation = MibIdentifier((1, 3, 6, 1, 2, 1, 161, 1, 3))
t11FcRscnRegTable = MibTable((1, 3, 6, 1, 2, 1, 161, 1, 1, 1), )
if mibBuilder.loadTexts: t11FcRscnRegTable.setDescription('A table of Nx_Ports that have registered to receive\n           RSCNs on all Fabrics configured on one or more Fibre\n           Channel switches.')
t11FcRscnRegEntry = MibTableRow((1, 3, 6, 1, 2, 1, 161, 1, 1, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-RSCN-MIB", "t11FcRscnFabricIndex"), (0, "T11-FC-RSCN-MIB", "t11FcRscnRegFcId"))
if mibBuilder.loadTexts: t11FcRscnRegEntry.setDescription('An entry containing information about one Nx_Port that\n           has registered with a particular switch (identified by\n           values of fcmInstanceIndex and fcmSwitchIndex) for a\n           particular Fabric (identified by a t11FcRscnFabricIndex\n           value).')
t11FcRscnFabricIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 1, 1, 1, 1), T11FabricIndex())
if mibBuilder.loadTexts: t11FcRscnFabricIndex.setDescription('An index value that uniquely identifies a particular\n           Fabric.\n\n           In a Fabric conformant to FC-SW-4, multiple Virtual Fabrics\n           can operate within one (or more) physical infrastructures.\n           In such a case, this index value is used to uniquely\n           identify a particular Fabric within a physical\n           infrastructure.\n\n           In a Fabric that has (or can have) only a single Fabric\n           operating within the physical infrastructure, the\n           value of this Fabric Index will always be 1.')
t11FcRscnRegFcId = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 1, 1, 1, 2), FcAddressIdOrZero().subtype(subtypeSpec=ValueSizeConstraint(3,3)).setFixedLength(3))
if mibBuilder.loadTexts: t11FcRscnRegFcId.setDescription('The Fibre Channel Address Identifier of the\n           registering Nx_Port.')
t11FcRscnRegType = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 1, 1, 1, 3), Bits().clone(namedValues=NamedValues(("fromFabricController", 0), ("fromNxPort", 1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnRegType.setDescription("This object indicates the type of registration\n           desired by the registering Nx_Port, one bit per type:\n\n           'fromFabricController' -- RSCNs generated for events\n\n\n\n                                  detected by the Fabric Controller.\n\n           'fromNxPorts'          -- RSCNs generated for events\n                                  detected by the affected Nx_Port.")
t11FcRscnStatsTable = MibTable((1, 3, 6, 1, 2, 1, 161, 1, 2, 1), )
if mibBuilder.loadTexts: t11FcRscnStatsTable.setDescription("The RSCN-related statistics on all Fabrics configured\n           on one or more Fibre Channel switches.\n\n           Two levels of statistics are included:\n\n              1) counters at the message-type level, for:\n                 - the number of SCRs received/rejected,\n                 - the number of RSCNs sent/received/rejected,\n                 - the number of SW_RSCNs sent/received/rejected.\n\n              2) counters of sent/received RSCNs per 'Event\n                 Qualifier' value.  Note that if and when several\n                 RSCN events are coalesced into a single RSCN\n                 message, then that message may be counted in\n                 more than one of these counters.")
t11FcRscnStatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-RSCN-MIB", "t11FcRscnFabricIndex"))
if mibBuilder.loadTexts: t11FcRscnStatsEntry.setDescription('An entry containing statistics for a particular Fabric\n           (identified by a t11FcRscnFabricIndex value) on a particular\n           switch (identified by values of fcmInstanceIndex and\n           fcmSwitchIndex).')
t11FcRscnInScrs = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnInScrs.setDescription('The number of SCRs received from Nx_Ports\n           by this switch on this Fabric.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.')
t11FcRscnInRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnInRscns.setDescription('The number of RSCNs received from Nx_Ports\n           by this switch on this Fabric.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.')
t11FcRscnOutRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnOutRscns.setDescription('The number of RSCNs transmitted to Nx_Ports\n           by this switch on this Fabric.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.')
t11FcRscnInSwRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnInSwRscns.setDescription('The number of SW_RSCNs received by this switch from\n           other switches on this Fabric.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.')
t11FcRscnOutSwRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnOutSwRscns.setDescription('The number of SW_RSCNs transmitted by this switch\n           from other switches on this Fabric.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.')
t11FcRscnScrRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnScrRejects.setDescription('The number of SCRs rejected by this switch on\n           this Fabric.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.')
t11FcRscnRscnRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnRscnRejects.setDescription('The number of RSCNs rejected by this switch on this\n           Fabric.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.')
t11FcRscnSwRscnRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnSwRscnRejects.setDescription('The number of SW_RSCN rejected by this switch on this\n           Fabric.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.')
t11FcRscnInUnspecifiedRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnInUnspecifiedRscns.setDescription("The number of Registered State Change Notifications\n           (RSCNs) received by this switch on this Fabric which\n           contained an RSCN Event Qualifier value of '0000'b\n           meaning 'Event is not specified'.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.")
t11FcRscnOutUnspecifiedRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnOutUnspecifiedRscns.setDescription("The number of Registered State Change Notifications\n           (RSCNs) sent by this switch on this Fabric which\n           contained an RSCN Event Qualifier value of '0000'b\n           meaning 'Event is not specified'.\n\n\n\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.")
t11FcRscnInChangedAttribRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnInChangedAttribRscns.setDescription("The number of Registered State Change Notifications\n           (RSCNs) received by this switch on this Fabric which\n           contained an RSCN Event Qualifier value of '0002'b\n           meaning 'Changed Port Attribute'.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.")
t11FcRscnOutChangedAttribRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnOutChangedAttribRscns.setDescription("The number of Registered State Change Notifications\n           (RSCNs) sent by this switch on this Fabric which\n           contained an RSCN Event Qualifier value of '0002'b\n           meaning 'Changed Port Attribute'.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.")
t11FcRscnInChangedServiceRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnInChangedServiceRscns.setDescription("The number of Registered State Change Notifications\n           (RSCNs) received by this switch on this Fabric which\n\n\n\n           contained an RSCN Event Qualifier value of '0003'b\n           meaning 'Changed Service Object'.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.")
t11FcRscnOutChangedServiceRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnOutChangedServiceRscns.setDescription("The number of Registered State Change Notifications\n           (RSCNs) sent by this switch on this Fabric which\n           contained an RSCN Event Qualifier value of '0003'b\n           meaning 'Changed Service Object'.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.")
t11FcRscnInChangedSwitchRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnInChangedSwitchRscns.setDescription("The number of Registered State Change Notifications\n           (RSCNs) received by this switch on this Fabric which\n           contained an RSCN Event Qualifier value of '0004'b\n           meaning 'Changed Switch Configuration'.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.")
t11FcRscnOutChangedSwitchRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnOutChangedSwitchRscns.setDescription("The number of Registered State Change Notifications\n           (RSCNs) sent by this switch on this Fabric which\n           contained an RSCN Event Qualifier value of '0004'b\n           meaning 'Changed Switch Configuration'.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.")
t11FcRscnInRemovedRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnInRemovedRscns.setDescription("The number of Registered State Change Notifications\n           (RSCNs) received by this switch on this Fabric which\n           contained an RSCN Event Qualifier value of '0005'b\n           meaning 'Removed Object'.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.")
t11FcRscnOutRemovedRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 2, 1, 1, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnOutRemovedRscns.setDescription("The number of Registered State Change Notifications\n           (RSCNs) sent by this switch on this Fabric which\n           contained an RSCN Event Qualifier value of '0005'b\n           meaning 'Removed Object'.\n\n           This counter has no discontinuities other than\n           those that all Counter32s have when sysUpTime=0.")
t11FcRscnNotifyControlTable = MibTable((1, 3, 6, 1, 2, 1, 161, 1, 3, 1), )
if mibBuilder.loadTexts: t11FcRscnNotifyControlTable.setDescription('A table of control information for notifications\n           generated due to the rejection of an SCR or RSCN.')
t11FcRscnNotifyControlEntry = MibTableRow((1, 3, 6, 1, 2, 1, 161, 1, 3, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-RSCN-MIB", "t11FcRscnFabricIndex"))
if mibBuilder.loadTexts: t11FcRscnNotifyControlEntry.setDescription('Each entry contains notification control information\n           concerning the rejection of RSCN/SCRs for a particular\n           Fabric (identified by the value of t11FcRscnFabricIndex)\n           by a particular switch (identified by values of\n           fcmInstanceIndex and fcmSwitchIndex).')
t11FcRscnIlsRejectNotifyEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 3, 1, 1, 1), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FcRscnIlsRejectNotifyEnable.setDescription('This object specifies if a t11FcRscnIlsRejectReqNotify\n           notification should be generated when this switch\n           rejects an SW_RSCN on this Fabric.\n\n           Values written to this object should be retained\n           over agent reboots.')
t11FcRscnElsRejectNotifyEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 3, 1, 1, 2), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11FcRscnElsRejectNotifyEnable.setDescription('This object specifies if a t11FcRscnElsRejectReqNotify\n           notification should be generated when this switch\n           rejects an RSCN or SCR on this Fabric.\n\n           Values written to this object should be retained\n           over agent reboots.')
t11FcRscnRejectedRequestString = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 3, 1, 1, 3), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnRejectedRequestString.setDescription('The binary content of the RSCN, SCR, or SW_RSCN that\n           was most recently rejected by this switch on this Fabric.\n           The value is formatted as an octet string (in network\n           byte order) as described in the relevant Fibre Channel\n           standard, containing the payload (which is typically a\n           list of affected ports and error codes) of the rejected\n           RSCN or SCR as described in FC-LS, or the rejected\n           SW_RSCN as described in FC-SW-4.\n\n           This object contains the zero-length string if and when\n           the RSCN/SCR/SW_RSCN payload is unavailable.  When the\n           length of this object is 255 octets, it contains the\n           first 255 octets of the payload (in network byte order).')
t11FcRscnRejectedRequestSource = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 3, 1, 1, 4), FcNameIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnRejectedRequestSource.setDescription('The WWN that was the source of the RSCN, SCR, or\n           SW_RSCN that was most recently rejected by this switch\n           on this Fabric.')
t11FcRscnRejectReasonCode = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 3, 1, 1, 5), T11NsGs4RejectReasonCode()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnRejectReasonCode.setDescription('This object contains the Reason Code of the most recent\n           rejection by this switch of an RSCN, SCR or SW_RSCN on\n           this Fabric.')
t11FcRscnRejectReasonCodeExp = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 3, 1, 1, 6), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,1)).setFixedLength(1)).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnRejectReasonCodeExp.setDescription('This object contains the Reason Code Explanation\n           of the most recent rejection by this switch of an\n           RSCN, SCR or SW_RSCN on this Fabric.')
t11FcRscnRejectReasonVendorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 161, 1, 3, 1, 1, 7), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,1)).setFixedLength(1)).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRscnRejectReasonVendorCode.setDescription('This object contains the Reason Vendor Specific\n           Code of the most recent rejection by this switch\n           of an RSCN, SCR or SW_RSCN on this Fabric.')
t11FcRscnElsRejectReqNotify = NotificationType((1, 3, 6, 1, 2, 1, 161, 0, 1)).setObjects(*(("T11-FC-RSCN-MIB", "t11FcRscnRejectedRequestString"), ("T11-FC-RSCN-MIB", "t11FcRscnRejectedRequestSource"), ("T11-FC-RSCN-MIB", "t11FcRscnRejectReasonCode"), ("T11-FC-RSCN-MIB", "t11FcRscnRejectReasonCodeExp"), ("T11-FC-RSCN-MIB", "t11FcRscnRejectReasonVendorCode"),))
if mibBuilder.loadTexts: t11FcRscnElsRejectReqNotify.setDescription('This notification is generated when a switch rejects\n           an SCR or RSCN.\n\n           The value of t11FcRscnRejectedRequestString indicates the\n           binary content of the rejected request if available, or\n           the zero-length string otherwise.  The source of the\n           rejected request is given by t11FcRscnRejectedRequestSource,\n           and the reason for rejection is given by the values of\n           t11FcRscnRejectReasonCode, t11FcRscnRejectReasonCodeExp\n           and t11FcRscnRejectReasonVendorCode.')
t11FcRscnIlsRejectReqNotify = NotificationType((1, 3, 6, 1, 2, 1, 161, 0, 2)).setObjects(*(("T11-FC-RSCN-MIB", "t11FcRscnRejectedRequestString"), ("T11-FC-RSCN-MIB", "t11FcRscnRejectedRequestSource"), ("T11-FC-RSCN-MIB", "t11FcRscnRejectReasonCode"), ("T11-FC-RSCN-MIB", "t11FcRscnRejectReasonCodeExp"), ("T11-FC-RSCN-MIB", "t11FcRscnRejectReasonVendorCode"),))
if mibBuilder.loadTexts: t11FcRscnIlsRejectReqNotify.setDescription('This notification is generated when a switch rejects\n           an SW_RSCN.\n\n           The value of t11FcRscnRejectedRequestString indicates the\n           binary content of the rejected request if available, or\n           the zero-length string otherwise.  The source of the\n           rejected request is given by t11FcRscnRejectedRequestSource,\n           and the reason for rejection is given by the values of\n           t11FcRscnRejectReasonCode, t11FcRscnRejectReasonCodeExp\n           and t11FcRscnRejectReasonVendorCode.')
t11FcRscnCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 161, 2, 1))
t11FcRscnGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 161, 2, 2))
t11FcRscnCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 161, 2, 1, 1)).setObjects(*(("T11-FC-RSCN-MIB", "t11FcRscnRegistrationGroup"), ("T11-FC-RSCN-MIB", "t11FcRscnNotifyControlGroup"), ("T11-FC-RSCN-MIB", "t11FcRscnNotifyGroup"), ("T11-FC-RSCN-MIB", "t11FcRscnStatsGroup"),))
if mibBuilder.loadTexts: t11FcRscnCompliance.setDescription('The compliance statement for entities that implement\n           this MIB.')
t11FcRscnRegistrationGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 161, 2, 2, 1)).setObjects(*(("T11-FC-RSCN-MIB", "t11FcRscnRegType"),))
if mibBuilder.loadTexts: t11FcRscnRegistrationGroup.setDescription('A collection of objects for monitoring RSCN\n           registrations.')
t11FcRscnStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 161, 2, 2, 2)).setObjects(*(("T11-FC-RSCN-MIB", "t11FcRscnInScrs"), ("T11-FC-RSCN-MIB", "t11FcRscnInRscns"), ("T11-FC-RSCN-MIB", "t11FcRscnOutRscns"), ("T11-FC-RSCN-MIB", "t11FcRscnInSwRscns"), ("T11-FC-RSCN-MIB", "t11FcRscnOutSwRscns"), ("T11-FC-RSCN-MIB", "t11FcRscnScrRejects"), ("T11-FC-RSCN-MIB", "t11FcRscnRscnRejects"), ("T11-FC-RSCN-MIB", "t11FcRscnSwRscnRejects"), ("T11-FC-RSCN-MIB", "t11FcRscnInUnspecifiedRscns"), ("T11-FC-RSCN-MIB", "t11FcRscnOutUnspecifiedRscns"), ("T11-FC-RSCN-MIB", "t11FcRscnInChangedAttribRscns"), ("T11-FC-RSCN-MIB", "t11FcRscnOutChangedAttribRscns"), ("T11-FC-RSCN-MIB", "t11FcRscnInChangedServiceRscns"), ("T11-FC-RSCN-MIB", "t11FcRscnOutChangedServiceRscns"), ("T11-FC-RSCN-MIB", "t11FcRscnInChangedSwitchRscns"), ("T11-FC-RSCN-MIB", "t11FcRscnOutChangedSwitchRscns"), ("T11-FC-RSCN-MIB", "t11FcRscnInRemovedRscns"), ("T11-FC-RSCN-MIB", "t11FcRscnOutRemovedRscns"),))
if mibBuilder.loadTexts: t11FcRscnStatsGroup.setDescription('A collection of objects for collecting RSCN-related\n           statistics.')
t11FcRscnNotifyControlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 161, 2, 2, 3)).setObjects(*(("T11-FC-RSCN-MIB", "t11FcRscnIlsRejectNotifyEnable"), ("T11-FC-RSCN-MIB", "t11FcRscnElsRejectNotifyEnable"), ("T11-FC-RSCN-MIB", "t11FcRscnRejectedRequestString"), ("T11-FC-RSCN-MIB", "t11FcRscnRejectedRequestSource"), ("T11-FC-RSCN-MIB", "t11FcRscnRejectReasonCode"), ("T11-FC-RSCN-MIB", "t11FcRscnRejectReasonCodeExp"), ("T11-FC-RSCN-MIB", "t11FcRscnRejectReasonVendorCode"),))
if mibBuilder.loadTexts: t11FcRscnNotifyControlGroup.setDescription('A collection of notification control and\n           notification information objects.')
t11FcRscnNotifyGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 161, 2, 2, 4)).setObjects(*(("T11-FC-RSCN-MIB", "t11FcRscnIlsRejectReqNotify"), ("T11-FC-RSCN-MIB", "t11FcRscnElsRejectReqNotify"),))
if mibBuilder.loadTexts: t11FcRscnNotifyGroup.setDescription('A collection of notifications for monitoring\n           ILS and ELS rejections by the RSCN module.')
mibBuilder.exportSymbols("T11-FC-RSCN-MIB", t11FcRscnInformation=t11FcRscnInformation, t11FcRscnRegEntry=t11FcRscnRegEntry, t11FcRscnInRemovedRscns=t11FcRscnInRemovedRscns, t11FcRscnNotifyControlTable=t11FcRscnNotifyControlTable, t11FcRscnRejectReasonCodeExp=t11FcRscnRejectReasonCodeExp, t11FcRscnElsRejectNotifyEnable=t11FcRscnElsRejectNotifyEnable, t11FcRscnSwRscnRejects=t11FcRscnSwRscnRejects, t11FcRscnRscnRejects=t11FcRscnRscnRejects, t11FcRscnInChangedServiceRscns=t11FcRscnInChangedServiceRscns, t11FcRscnCompliance=t11FcRscnCompliance, t11FcRscnOutRscns=t11FcRscnOutRscns, t11FcRscnStatsEntry=t11FcRscnStatsEntry, t11FcRscnRejectReasonCode=t11FcRscnRejectReasonCode, t11FcRscnRegistrationGroup=t11FcRscnRegistrationGroup, t11FcRscnConformance=t11FcRscnConformance, t11FcRscnInChangedAttribRscns=t11FcRscnInChangedAttribRscns, t11FcRscnRegistrations=t11FcRscnRegistrations, t11FcRscnCompliances=t11FcRscnCompliances, t11FcRscnStatsGroup=t11FcRscnStatsGroup, t11FcRscnInSwRscns=t11FcRscnInSwRscns, t11FcRscnInRscns=t11FcRscnInRscns, t11FcRscnIlsRejectReqNotify=t11FcRscnIlsRejectReqNotify, t11FcRscnNotifyGroup=t11FcRscnNotifyGroup, t11FcRscnRegType=t11FcRscnRegType, t11FcRscnOutRemovedRscns=t11FcRscnOutRemovedRscns, t11FcRscnInChangedSwitchRscns=t11FcRscnInChangedSwitchRscns, t11FcRscnStatsTable=t11FcRscnStatsTable, t11FcRscnInUnspecifiedRscns=t11FcRscnInUnspecifiedRscns, t11FcRscnStats=t11FcRscnStats, t11FcRscnNotifyControlEntry=t11FcRscnNotifyControlEntry, t11FcRscnNotifyControlGroup=t11FcRscnNotifyControlGroup, t11FcRscnElsRejectReqNotify=t11FcRscnElsRejectReqNotify, t11FcRscnInScrs=t11FcRscnInScrs, t11FcRscnRejectedRequestSource=t11FcRscnRejectedRequestSource, t11FcRscnGroups=t11FcRscnGroups, t11FcRscnMIB=t11FcRscnMIB, t11FcRscnRegFcId=t11FcRscnRegFcId, t11FcRscnObjects=t11FcRscnObjects, t11FcRscnRejectedRequestString=t11FcRscnRejectedRequestString, t11FcRscnOutSwRscns=t11FcRscnOutSwRscns, PYSNMP_MODULE_ID=t11FcRscnMIB, t11FcRscnOutChangedServiceRscns=t11FcRscnOutChangedServiceRscns, t11FcRscnOutChangedSwitchRscns=t11FcRscnOutChangedSwitchRscns, t11FcRscnNotifications=t11FcRscnNotifications, t11FcRscnOutUnspecifiedRscns=t11FcRscnOutUnspecifiedRscns, t11FcRscnScrRejects=t11FcRscnScrRejects, t11FcRscnRegTable=t11FcRscnRegTable, t11FcRscnIlsRejectNotifyEnable=t11FcRscnIlsRejectNotifyEnable, t11FcRscnOutChangedAttribRscns=t11FcRscnOutChangedAttribRscns, t11FcRscnFabricIndex=t11FcRscnFabricIndex, t11FcRscnRejectReasonVendorCode=t11FcRscnRejectReasonVendorCode)



#
# PySNMP MIB module HC-PerfHist-TC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/HC-PerfHist-TC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:03:54 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ValueRangeConstraint, ValueSizeConstraint, ConstraintsIntersection, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsIntersection", "ConstraintsUnion")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( Gauge32, TimeTicks, ObjectIdentity, ModuleIdentity, Bits, Counter32, IpAddress, MibIdentifier, Integer32, Counter64, Unsigned32, mib_2, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Gauge32", "TimeTicks", "ObjectIdentity", "ModuleIdentity", "Bits", "Counter32", "IpAddress", "MibIdentifier", "Integer32", "Counter64", "Unsigned32", "mib-2", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
hcPerfHistTCMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 107)).setRevisions(("2004-02-03 00:00",))
if mibBuilder.loadTexts: hcPerfHistTCMIB.setLastUpdated('200402030000Z')
if mibBuilder.loadTexts: hcPerfHistTCMIB.setOrganization('ADSLMIB Working Group')
if mibBuilder.loadTexts: hcPerfHistTCMIB.setContactInfo('WG-email:  adslmib@ietf.org\n           Info:      https://www1.ietf.org/mailman/listinfo/adslmib\n\n           Chair:     Mike Sneed\n                      Sand Channel Systems\n           Postal:    P.O.  Box 37324\n                      Raleigh NC 27627-7324\n                      USA\n           Email:     sneedmike@hotmail.com\n           Phone:     +1 206 600 7022\n\n           Co-editor: Bob Ray\n                      PESA Switching Systems, Inc.\n           Postal:    330-A Wynn Drive\n                      Huntsville, AL 35805\n                      USA\n           Email:     rray@pesa.com\n           Phone:     +1 256 726 9200 ext.  142\n\n           Co-editor: Rajesh Abbi\n                      Alcatel USA\n           Postal:    2301 Sugar Bush Road\n                      Raleigh, NC 27612-3339\n                      USA\n           Email:     Rajesh.Abbi@alcatel.com\n           Phone:     +1 919 850 6194\n           ')
if mibBuilder.loadTexts: hcPerfHistTCMIB.setDescription('This MIB Module provides Textual Conventions to be\n            used by systems supporting 15 minute based performance\n            history counts that require high-capacity counts.\n\n            Copyright (C) The Internet Society (2004).  This version\n            of this MIB module is part of RFC 3705: see the RFC\n            itself for full legal notices.')
class HCPerfValidIntervals(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,96)

class HCPerfInvalidIntervals(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,96)

class HCPerfTimeElapsed(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,86399)

class HCPerfIntervalThreshold(Unsigned32, TextualConvention):
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(0,900)

class HCPerfCurrentCount(Counter64, TextualConvention):
    pass

class HCPerfIntervalCount(Counter64, TextualConvention):
    pass

class HCPerfTotalCount(Counter64, TextualConvention):
    pass

mibBuilder.exportSymbols("HC-PerfHist-TC-MIB", HCPerfTimeElapsed=HCPerfTimeElapsed, HCPerfTotalCount=HCPerfTotalCount, HCPerfIntervalCount=HCPerfIntervalCount, HCPerfCurrentCount=HCPerfCurrentCount, HCPerfValidIntervals=HCPerfValidIntervals, hcPerfHistTCMIB=hcPerfHistTCMIB, HCPerfInvalidIntervals=HCPerfInvalidIntervals, HCPerfIntervalThreshold=HCPerfIntervalThreshold, PYSNMP_MODULE_ID=hcPerfHistTCMIB)



#
# PySNMP MIB module IFCP-MGMT-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IFCP-MGMT-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:16:39 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ConstraintsUnion, ValueSizeConstraint, ValueRangeConstraint, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ConstraintsUnion", "ValueSizeConstraint", "ValueRangeConstraint", "SingleValueConstraint")
( PhysicalIndexOrZero, ) = mibBuilder.importSymbols("ENTITY-MIB", "PhysicalIndexOrZero")
( FcAddressIdOrZero, FcNameIdOrZero, ) = mibBuilder.importSymbols("FC-MGMT-MIB", "FcAddressIdOrZero", "FcNameIdOrZero")
( ZeroBasedCounter64, ) = mibBuilder.importSymbols("HCNUM-TC", "ZeroBasedCounter64")
( InterfaceIndexOrZero, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndexOrZero")
( InetAddress, InetPortNumber, InetAddressType, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddress", "InetPortNumber", "InetAddressType")
( ZeroBasedCounter32, ) = mibBuilder.importSymbols("RMON2-MIB", "ZeroBasedCounter32")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( MibIdentifier, Counter64, ModuleIdentity, Gauge32, Unsigned32, Counter32, ObjectIdentity, transmission, iso, NotificationType, TimeTicks, MibScalar, MibTable, MibTableRow, MibTableColumn, Integer32, IpAddress, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibIdentifier", "Counter64", "ModuleIdentity", "Gauge32", "Unsigned32", "Counter32", "ObjectIdentity", "transmission", "iso", "NotificationType", "TimeTicks", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Integer32", "IpAddress", "Bits")
( TruthValue, TextualConvention, StorageType, DisplayString, TimeStamp, ) = mibBuilder.importSymbols("SNMPv2-TC", "TruthValue", "TextualConvention", "StorageType", "DisplayString", "TimeStamp")
ifcpMgmtMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 230)).setRevisions(("2006-01-17 00:00",))
if mibBuilder.loadTexts: ifcpMgmtMIB.setLastUpdated('200601170000Z')
if mibBuilder.loadTexts: ifcpMgmtMIB.setOrganization('IETF IPS Working Group')
if mibBuilder.loadTexts: ifcpMgmtMIB.setContactInfo('\n           Attn: Kevin Gibbons\n                 McDATA Corporation\n                 4555 Great America Pkwy\n                 Santa Clara, CA 95054-1208 USA\n                 Phone: (408) 567-5765\n                 EMail: kevin.gibbons@mcdata.com\n\n                 Charles Monia\n                 Consultant\n                 7553 Morevern Circle\n                 San Jose, CA 95135 USA\n                 EMail: charles_monia@yahoo.com\n\n                 Josh Tseng\n                 Riverbed Technology\n                 501 2nd Street, Suite 410\n                 San Francisco, CA 94107 USA\n                 Phone: (650) 274-2109\n                 EMail: joshtseng@yahoo.com\n\n                 Franco Travostino\n                 Nortel\n                 600 Technology Park Drive\n                 Billerica, MA 01821 USA\n                 Phone: (978) 288-7708\n                 EMail: travos@nortel.com')
if mibBuilder.loadTexts: ifcpMgmtMIB.setDescription('This module defines management information specific\n                  to internet Fibre Channel Protocol (iFCP) gateway\n                  management.\n\n                  Copyright (C) The Internet Society 2006.  This\n                  version of this MIB module is part of RFC 4369; see\n                  the RFC itself for full legal notices.')
class IfcpIpTOVorZero(Unsigned32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(0,3600)

class IfcpLTIorZero(Unsigned32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(0,65535)

class IfcpSessionStates(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("down", 1), ("openPending", 2), ("open", 3),)

class IfcpAddressMode(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("addressTransparent", 1), ("addressTranslation", 2),)

ifcpGatewayObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 230, 1))
ifcpGatewayConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 230, 2))
ifcpLclGatewayInfo = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 230, 1, 1))
ifcpLclGtwyInstTable = MibTable((1, 3, 6, 1, 2, 1, 10, 230, 1, 1, 1), )
if mibBuilder.loadTexts: ifcpLclGtwyInstTable.setDescription('Information about all local iFCP Gateway instances that can\n    be monitored and controlled.  This table contains an entry\n    for each local iFCP Gateway instance that is being managed.')
ifcpLclGtwyInstEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 230, 1, 1, 1, 1), ).setIndexNames((0, "IFCP-MGMT-MIB", "ifcpLclGtwyInstIndex"))
if mibBuilder.loadTexts: ifcpLclGtwyInstEntry.setDescription('An entry in the local iFCP Gateway Instance table.\n    Parameters and settings for the gateway are found here.')
ifcpLclGtwyInstIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 1, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: ifcpLclGtwyInstIndex.setDescription('An arbitrary integer value to uniquely identify this iFCP\n    Gateway from other local Gateway instances.')
ifcpLclGtwyInstPhyIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 1, 1, 1, 2), PhysicalIndexOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpLclGtwyInstPhyIndex.setDescription('An index indicating the location of this local gateway within\n    a larger entity, if one exists.  If supported, this is the\n    entPhysicalIndex from the Entity MIB (Version 3), for this\n    iFCP Gateway.  If not supported, or if not related to a\n    physical entity, then the value of this object is 0.')
ifcpLclGtwyInstVersionMin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 1, 1, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpLclGtwyInstVersionMin.setDescription('The minimum iFCP protocol version supported by the local iFCP\n    gateway instance.')
ifcpLclGtwyInstVersionMax = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 1, 1, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpLclGtwyInstVersionMax.setDescription('The maximum iFCP protocol version supported by the local iFCP\n    gateway instance.')
ifcpLclGtwyInstAddrTransMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 1, 1, 1, 5), IfcpAddressMode().clone('addressTranslation')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ifcpLclGtwyInstAddrTransMode.setDescription('The local iFCP gateway operating mode.  Changing this value\n    may cause existing sessions to be disrupted.')
ifcpLclGtwyInstFcBrdcstSupport = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 1, 1, 1, 6), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ifcpLclGtwyInstFcBrdcstSupport.setDescription('Whether the local iFCP gateway supports FC Broadcast.\n    Changing this value may cause existing sessions to be\n    disrupted.')
ifcpLclGtwyInstDefaultIpTOV = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 1, 1, 1, 7), IfcpIpTOVorZero().clone(6)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ifcpLclGtwyInstDefaultIpTOV.setDescription('The default IP_TOV used for iFCP sessions at this gateway.\n    This is the default maximum propagation delay that will be\n    used for an iFCP session.  The value can be changed on a\n    per-session basis.  The valid range is 0 - 3600 seconds.\n    A value of 0 implies that fibre channel frame lifetime limits\n    will not be enforced.')
ifcpLclGtwyInstDefaultLTInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 1, 1, 1, 8), IfcpLTIorZero().clone(10)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ifcpLclGtwyInstDefaultLTInterval.setDescription('The default Liveness Test Interval (LTI), in seconds, used\n    for iFCP sessions at this gateway.  This is the default\n    value for an iFCP session and can be changed on a\n    per-session basis.  The valid range is 0 - 65535 seconds.\n    A value of 0 implies no Liveness Test Interval will be\n    performed on a session.')
ifcpLclGtwyInstDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 1, 1, 1, 9), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,64))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ifcpLclGtwyInstDescr.setDescription('A user-entered description for this iFCP Gateway.')
ifcpLclGtwyInstNumActiveSessions = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 1, 1, 1, 10), Gauge32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295))).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpLclGtwyInstNumActiveSessions.setDescription('The current total number of iFCP sessions in the open or\n    open-pending state.')
ifcpLclGtwyInstStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 1, 1, 1, 11), StorageType().clone('nonVolatile')).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpLclGtwyInstStorageType.setDescription('The storage type for this row.  Parameter values defined\n    for a gateway are usually non-volatile, but may be volatile\n    or permanent in some configurations.  If permanent, then\n    the following parameters must have read-write access:\n    ifcpLclGtwyInstAddrTransMode, ifcpLclGtwyInstDefaultIpTOV,\n    and ifcpLclGtwyInstDefaultLTInterval.')
ifcpNportSessionInfo = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 230, 1, 2))
ifcpSessionAttributesTable = MibTable((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1), )
if mibBuilder.loadTexts: ifcpSessionAttributesTable.setDescription('An iFCP session consists of the pair of N_PORTs comprising\n    the session endpoints joined by a single TCP/IP connection.\n    This table provides information on each iFCP session\n    currently using a local iFCP Gateway instance.  iFCP sessions\n    are created and removed by the iFCP Gateway instances, which\n    are reflected in this table.')
ifcpSessionAttributesEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1), ).setIndexNames((0, "IFCP-MGMT-MIB", "ifcpLclGtwyInstIndex"), (0, "IFCP-MGMT-MIB", "ifcpSessionIndex"))
if mibBuilder.loadTexts: ifcpSessionAttributesEntry.setDescription("Each entry contains information about one iFCP session consisting\n    of a pair of N_PORTs joined by a single TCP/IP connection.  This\n    table's INDEX includes ifcpLclGtwyInstIndex, which identifies the\n    local iFCP Gateway instance that created the session for the\n    entry.\n\n    Soon after an entry is created in this table for an iFCP session, it\n    will correspond to an entry in the tcpConnectionTable of the TCP-MIB\n    (RFC 4022).  The corresponding entry might represent a preexisting\n    TCP connection, or it might be a newly-created entry.  (Note that if\n    IPv4 is being used, an entry in RFC 2012's tcpConnTable may also\n    correspond.)  The values of ifcpSessionLclPrtlAddrType and\n    ifcpSessionRmtPrtlIfAddrType in this table and the values of\n    tcpConnectionLocalAddressType and tcpConnectionRemAddressType used\n    as INDEX values for the corresponding entry in the\n    tcpConnectionTable should be the same; this makes it simpler to\n    locate a session's TCP connection in the TCP-MIB.  (Of course, all\n    four values need to be 'ipv4' if there's a corresponding entry in\n    the tcpConnTable.)\n\n    If an entry is created in this table for a session, prior to\n    knowing which local and/or remote port numbers will be used for\n    the TCP connection, then ifcpSessionLclPrtlTcpPort and/or\n    ifcpSessionRmtPrtlTcpPort have the value zero until such time as\n    they can be updated to the port numbers (to be) used for the\n    connection.  (Thus, a port value of zero should not be used to\n    locate a session's TCP connection in the TCP-MIB.)\n\n    When the TCP connection terminates, the entry in the\n    tcpConnectionTable and the entry in this table both get deleted\n    (and, if applicable, so does the entry in the tcpConnTable).")
ifcpSessionIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: ifcpSessionIndex.setDescription('The iFCP session index is a unique value used as an index\n    to the table, along with a specific local iFCP Gateway\n    instance.  This index is used because the local N Port and\n    remote N Port information would create an complex index that\n    would be difficult to implement.')
ifcpSessionLclPrtlIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 2), InterfaceIndexOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLclPrtlIfIndex.setDescription('This is the interface index in the IF-MIB ifTable being used\n    as the local portal in this session, as described in the\n    IF-MIB.  If the local portal is not associated with an entry\n    in the ifTable, then the value is 0.  The ifType of the\n    interface will generally be a type that supports IP, but an\n    implementation may support iFCP using other protocols.  This\n    object can be used to obtain additional information about the\n    interface.')
ifcpSessionLclPrtlAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 3), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLclPrtlAddrType.setDescription('The type of address in ifcpSessionLclIfAddr.')
ifcpSessionLclPrtlAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 4), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLclPrtlAddr.setDescription('This is the external IP address of the interface being used\n    for the iFCP local portal in this session.  The address type\n    is defined in ifcpSessionLclPrtlAddrType.  If the value is a\n    DNS name, then the name is resolved once, during the initial\n    session instantiation.')
ifcpSessionLclPrtlTcpPort = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 5), InetPortNumber()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLclPrtlTcpPort.setDescription('This is the TCP port number that is being used for the iFCP\n    local portal in this session.  This is normally an ephemeral\n    port number selected by the gateway.  The value may be 0\n    during an initial setup period.')
ifcpSessionLclNpWwun = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 6), FcNameIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLclNpWwun.setDescription('World Wide Unique Name of the local N Port.  For an unbound\n    session, this variable will be a zero-length string.')
ifcpSessionLclNpFcid = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 7), FcAddressIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLclNpFcid.setDescription('Fibre Channel Identifier of the local N Port.  For an unbound\n    session, this variable will be a zero-length string.')
ifcpSessionRmtNpWwun = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 8), FcNameIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionRmtNpWwun.setDescription('World Wide Unique Name of the remote N Port.  For an unbound\n    session, this variable will be a zero-length string.')
ifcpSessionRmtPrtlIfAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 9), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionRmtPrtlIfAddrType.setDescription('The type of address in ifcpSessionRmtPrtlIfAddr.')
ifcpSessionRmtPrtlIfAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 10), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionRmtPrtlIfAddr.setDescription('This is the remote gateway IP address being used for the\n    portal on the remote iFCP gateway.  The address type is\n    defined in ifcpSessionRmtPrtlIfAddrType.  If the value is a\n    DNS name, then the name is resolved once, during the initial\n    session instantiation.')
ifcpSessionRmtPrtlTcpPort = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 11), InetPortNumber().clone(3420)).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionRmtPrtlTcpPort.setDescription('This is the TCP port number being used for the portal on the\n    remote iFCP gateway.  Generally, this will be the iFCP\n    canonical port.  The value may be 0 during an initial setup\n    period.')
ifcpSessionRmtNpFcid = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 12), FcAddressIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionRmtNpFcid.setDescription('Fibre Channel Identifier of the remote N Port.  For an\n    unbound session, this variable will be a zero-length string.')
ifcpSessionRmtNpFcidAlias = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 13), FcAddressIdOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionRmtNpFcidAlias.setDescription('Fibre Channel Identifier Alias assigned by the local gateway\n    for the remote N Port.  For an unbound session, this variable\n    will be a zero-length string.')
ifcpSessionIpTOV = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 14), IfcpIpTOVorZero()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ifcpSessionIpTOV.setDescription('The IP_TOV being used for this iFCP session.  This is the\n    maximum propagation delay that will be used for the iFCP\n    session.  The value can be changed on a per-session basis\n    and initially defaults to ifcpLclGtwyInstDefaultIpTOV for\n    the local gateway instance.  The valid range is 0 - 3600\n    seconds.  A value of 0 implies fibre channel frame lifetime\n    limits will not be enforced.')
ifcpSessionLclLTIntvl = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 15), IfcpLTIorZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLclLTIntvl.setDescription('The Liveness Test Interval (LTI) used for this iFCP session.\n    The value can be changed on a per-session basis and initially\n    defaults to ifcpLclGtwyInstDefaultLTInterval for the local\n    gateway instance.  The valid range is 0 - 65535 seconds.\n    A value of 0 implies that the gateway will not originate\n    Liveness Test messages for the session.')
ifcpSessionRmtLTIntvl = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 16), IfcpLTIorZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionRmtLTIntvl.setDescription('The Liveness Test Interval (LTI) as requested by the remote\n    gateway instance to use for this iFCP session.  This value may\n    change over the life of the session.  The valid range is 0 -\n    65535 seconds.  A value of 0 implies that the remote gateway\n    has not been requested to originate Liveness Test messages for\n    the session.')
ifcpSessionBound = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 17), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionBound.setDescription('This value indicates whether this session is bound to a\n    specific local and remote N Port.  Sessions by default are\n    unbound and ready for future assignment to a local and remote\n    N Port.')
ifcpSessionStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 1, 1, 18), StorageType().clone('nonVolatile')).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionStorageType.setDescription('The storage type for this row.  Parameter values defined\n    for a session are usually non-volatile, but may be volatile\n    or permanent in some configurations.  If permanent, then\n    ifcpSessionIpTOV must have read-write access.')
ifcpSessionStatsTable = MibTable((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 2), )
if mibBuilder.loadTexts: ifcpSessionStatsTable.setDescription('This table provides statistics on an iFCP session.')
ifcpSessionStatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 2, 1), )
ifcpSessionAttributesEntry.registerAugmentions(("IFCP-MGMT-MIB", "ifcpSessionStatsEntry"))
ifcpSessionStatsEntry.setIndexNames(*ifcpSessionAttributesEntry.getIndexNames())
if mibBuilder.loadTexts: ifcpSessionStatsEntry.setDescription('Provides iFCP-specific statistics per session.')
ifcpSessionState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 2, 1, 1), IfcpSessionStates()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionState.setDescription('The current session operating state.')
ifcpSessionDuration = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 2, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295))).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionDuration.setDescription('This indicates, in seconds, how long the iFCP session has\n    been in an open or open-pending state.  When a session is\n    down, the value is reset to 0.')
ifcpSessionTxOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 2, 1, 3), ZeroBasedCounter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionTxOctets.setDescription('The total number of octets transmitted by the iFCP gateway\n    for this session.  Discontinuities in the value of this\n    counter can occur at reinitialization of the management\n    system, and at other times as indicated by the value of\n    ifcpSessionDiscontinuityTime.')
ifcpSessionRxOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 2, 1, 4), ZeroBasedCounter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionRxOctets.setDescription('The total number of octets received by the iFCP gateway for\n    this session.  Discontinuities in the value of this\n    counter can occur at reinitialization of the management\n    system, and at other times as indicated by the value of\n    ifcpSessionDiscontinuityTime.')
ifcpSessionTxFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 2, 1, 5), ZeroBasedCounter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionTxFrames.setDescription('The total number of iFCP frames transmitted by the gateway\n    for this session.  Discontinuities in the value of this\n    counter can occur at reinitialization of the management\n    system, and at other times as indicated by the value of\n    ifcpSessionDiscontinuityTime.')
ifcpSessionRxFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 2, 1, 6), ZeroBasedCounter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionRxFrames.setDescription('The total number of iFCP frames received by the gateway\n    for this session.  Discontinuities in the value of this\n    counter can occur at reinitialization of the management\n    system, and at other times as indicated by the value of\n    ifcpSessionDiscontinuityTime.')
ifcpSessionStaleFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 2, 1, 7), ZeroBasedCounter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionStaleFrames.setDescription('The total number of received iFCP frames that were stale and\n    discarded by the gateway for this session.  Discontinuities\n    in the value of this counter can occur at reinitialization\n    of the management system, and at other times as indicated by\n    the value of ifcpSessionDiscontinuityTime.')
ifcpSessionHeaderCRCErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 2, 1, 8), ZeroBasedCounter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionHeaderCRCErrors.setDescription('The total number of CRC errors that occurred in the frame\n    header, detected by the gateway for this session.  Usually,\n    a single Header CRC error is sufficient to terminate an\n    iFCP session.  Discontinuities in the value of this\n    counter can occur at reinitialization of the management\n    system, and at other times as indicated by the value of\n    ifcpSessionDiscontinuityTime.')
ifcpSessionFcPayloadCRCErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 2, 1, 9), ZeroBasedCounter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionFcPayloadCRCErrors.setDescription('The total number of CRC errors that occurred in the Fibre\n    Channel frame payload, detected by the gateway for this\n    session.  Discontinuities in the value of this counter can\n    occur at reinitialization of the management system, and\n    at other times as indicated by the value of\n    ifcpSessionDiscontinuityTime.')
ifcpSessionOtherErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 2, 1, 10), ZeroBasedCounter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionOtherErrors.setDescription('The total number of errors, other than errors explicitly\n    measured, detected by the gateway for this session.\n    Discontinuities in the value of this counter can occur at\n    reinitialization of the management system, and at other\n    times as indicated by the value of\n    ifcpSessionDiscontinuityTime.')
ifcpSessionDiscontinuityTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 2, 1, 11), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionDiscontinuityTime.setDescription('The value of sysUpTime on the most recent occasion at which\n    any one (or more) of the ifcpSessionStatsTable counters\n    suffered a discontinuity.  The relevant counters are the\n    specific Counter64-based instances associated with the\n    ifcpSessionStatsTable: ifcpSessionTxOctets,\n    ifcpSessionRxOctets, ifcpSessionTxFrames,\n    ifcpSessionRxFrames, ifcpSessionStaleFrames,\n    ifcpSessionHeaderCRCErrors, ifcpSessionFcPayloadCRCErrors,\n    and ifcpSessionOtherErrors.  If no such discontinuities have\n    occurred since the last reinitialization of the local\n    management subsystem, then this object contains a zero value.')
ifcpSessionLcStatsTable = MibTable((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 3), )
if mibBuilder.loadTexts: ifcpSessionLcStatsTable.setDescription('This table provides low capacity statistics for an iFCP\n    session.  These are provided for backward compatibility with\n    systems that do not support Counter64-based objects.  At\n    1-Gbps rates, a Counter32-based object can wrap as often as\n    every 34 seconds.  Counter32-based objects can be sufficient\n    for many situations.  However, when possible, it is\n    recommended to use the high capacity statistics in\n    ifcpSessionStatsTable based on Counter64 objects.')
ifcpSessionLcStatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 3, 1), )
ifcpSessionAttributesEntry.registerAugmentions(("IFCP-MGMT-MIB", "ifcpSessionLcStatsEntry"))
ifcpSessionLcStatsEntry.setIndexNames(*ifcpSessionAttributesEntry.getIndexNames())
if mibBuilder.loadTexts: ifcpSessionLcStatsEntry.setDescription('Provides iFCP-specific statistics per session.')
ifcpSessionLcTxOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 3, 1, 1), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLcTxOctets.setDescription('The total number of octets transmitted by the iFCP gateway\n    for this session.')
ifcpSessionLcRxOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 3, 1, 2), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLcRxOctets.setDescription('The total number of octets received by the iFCP gateway for\n    this session.')
ifcpSessionLcTxFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 3, 1, 3), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLcTxFrames.setDescription('The total number of iFCP frames transmitted by the gateway\n    for this session.')
ifcpSessionLcRxFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 3, 1, 4), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLcRxFrames.setDescription('The total number of iFCP frames received by the gateway\n    for this session.')
ifcpSessionLcStaleFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 3, 1, 5), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLcStaleFrames.setDescription('The total number of received iFCP frames that were stale and\n    discarded by the gateway for this session.')
ifcpSessionLcHeaderCRCErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 3, 1, 6), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLcHeaderCRCErrors.setDescription('The total number of CRC errors that occurred in the frame\n    header, detected by the gateway for this session.  Usually,\n    a single Header CRC error is sufficient to terminate an\n    iFCP session.')
ifcpSessionLcFcPayloadCRCErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 3, 1, 7), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLcFcPayloadCRCErrors.setDescription('The total number of CRC errors that occurred in the Fibre\n    Channel frame payload, detected by the gateway for this\n    session.')
ifcpSessionLcOtherErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 230, 1, 2, 3, 1, 8), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifcpSessionLcOtherErrors.setDescription('The total number of errors, other than errors explicitly\n    measured, detected by the gateway for this session.')
ifcpCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 230, 2, 1))
ifcpGatewayCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 230, 2, 1, 1)).setObjects(*(("IFCP-MGMT-MIB", "ifcpLclGatewayGroup"), ("IFCP-MGMT-MIB", "ifcpLclGatewaySessionGroup"), ("IFCP-MGMT-MIB", "ifcpLclGatewaySessionStatsGroup"), ("IFCP-MGMT-MIB", "ifcpLclGatewaySessionLcStatsGroup"),))
if mibBuilder.loadTexts: ifcpGatewayCompliance.setDescription('Implementation requirements for iFCP MIB compliance.')
ifcpGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 230, 2, 2))
ifcpLclGatewayGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 230, 2, 2, 1)).setObjects(*(("IFCP-MGMT-MIB", "ifcpLclGtwyInstPhyIndex"), ("IFCP-MGMT-MIB", "ifcpLclGtwyInstVersionMin"), ("IFCP-MGMT-MIB", "ifcpLclGtwyInstVersionMax"), ("IFCP-MGMT-MIB", "ifcpLclGtwyInstAddrTransMode"), ("IFCP-MGMT-MIB", "ifcpLclGtwyInstFcBrdcstSupport"), ("IFCP-MGMT-MIB", "ifcpLclGtwyInstDefaultIpTOV"), ("IFCP-MGMT-MIB", "ifcpLclGtwyInstDefaultLTInterval"), ("IFCP-MGMT-MIB", "ifcpLclGtwyInstDescr"), ("IFCP-MGMT-MIB", "ifcpLclGtwyInstNumActiveSessions"), ("IFCP-MGMT-MIB", "ifcpLclGtwyInstStorageType"),))
if mibBuilder.loadTexts: ifcpLclGatewayGroup.setDescription('iFCP local device info group.  This group provides\n    information about each gateway.')
ifcpLclGatewaySessionGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 230, 2, 2, 4)).setObjects(*(("IFCP-MGMT-MIB", "ifcpSessionLclPrtlIfIndex"), ("IFCP-MGMT-MIB", "ifcpSessionLclPrtlAddrType"), ("IFCP-MGMT-MIB", "ifcpSessionLclPrtlAddr"), ("IFCP-MGMT-MIB", "ifcpSessionLclPrtlTcpPort"), ("IFCP-MGMT-MIB", "ifcpSessionLclNpWwun"), ("IFCP-MGMT-MIB", "ifcpSessionLclNpFcid"), ("IFCP-MGMT-MIB", "ifcpSessionRmtNpWwun"), ("IFCP-MGMT-MIB", "ifcpSessionRmtPrtlIfAddrType"), ("IFCP-MGMT-MIB", "ifcpSessionRmtPrtlIfAddr"), ("IFCP-MGMT-MIB", "ifcpSessionRmtPrtlTcpPort"), ("IFCP-MGMT-MIB", "ifcpSessionRmtNpFcid"), ("IFCP-MGMT-MIB", "ifcpSessionRmtNpFcidAlias"), ("IFCP-MGMT-MIB", "ifcpSessionIpTOV"), ("IFCP-MGMT-MIB", "ifcpSessionLclLTIntvl"), ("IFCP-MGMT-MIB", "ifcpSessionRmtLTIntvl"), ("IFCP-MGMT-MIB", "ifcpSessionBound"), ("IFCP-MGMT-MIB", "ifcpSessionStorageType"),))
if mibBuilder.loadTexts: ifcpLclGatewaySessionGroup.setDescription('iFCP Session group.  This group provides information\n    about each iFCP session currently active between iFCP\n    gateways.')
ifcpLclGatewaySessionStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 230, 2, 2, 5)).setObjects(*(("IFCP-MGMT-MIB", "ifcpSessionState"), ("IFCP-MGMT-MIB", "ifcpSessionDuration"), ("IFCP-MGMT-MIB", "ifcpSessionTxOctets"), ("IFCP-MGMT-MIB", "ifcpSessionRxOctets"), ("IFCP-MGMT-MIB", "ifcpSessionTxFrames"), ("IFCP-MGMT-MIB", "ifcpSessionRxFrames"), ("IFCP-MGMT-MIB", "ifcpSessionStaleFrames"), ("IFCP-MGMT-MIB", "ifcpSessionHeaderCRCErrors"), ("IFCP-MGMT-MIB", "ifcpSessionFcPayloadCRCErrors"), ("IFCP-MGMT-MIB", "ifcpSessionOtherErrors"), ("IFCP-MGMT-MIB", "ifcpSessionDiscontinuityTime"),))
if mibBuilder.loadTexts: ifcpLclGatewaySessionStatsGroup.setDescription('iFCP Session Statistics group.  This group provides\n    statistics with 64-bit counters for each iFCP session\n    currently active between iFCP gateways.  This group\n    is only required for agents that can support Counter64-\n    based data types.')
ifcpLclGatewaySessionLcStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 230, 2, 2, 6)).setObjects(*(("IFCP-MGMT-MIB", "ifcpSessionLcTxOctets"), ("IFCP-MGMT-MIB", "ifcpSessionLcRxOctets"), ("IFCP-MGMT-MIB", "ifcpSessionLcTxFrames"), ("IFCP-MGMT-MIB", "ifcpSessionLcRxFrames"), ("IFCP-MGMT-MIB", "ifcpSessionLcStaleFrames"), ("IFCP-MGMT-MIB", "ifcpSessionLcHeaderCRCErrors"), ("IFCP-MGMT-MIB", "ifcpSessionLcFcPayloadCRCErrors"), ("IFCP-MGMT-MIB", "ifcpSessionLcOtherErrors"),))
if mibBuilder.loadTexts: ifcpLclGatewaySessionLcStatsGroup.setDescription('iFCP Session Low Capacity Statistics group.  This group\n    provides statistics with low-capacity 32-bit counters\n    for each iFCP session currently active between iFCP\n    gateways.  This group is only required for agents that\n    do not support Counter64-based data types, or that need\n    to support SNMPv1 applications.')
mibBuilder.exportSymbols("IFCP-MGMT-MIB", ifcpNportSessionInfo=ifcpNportSessionInfo, ifcpSessionStaleFrames=ifcpSessionStaleFrames, ifcpSessionDuration=ifcpSessionDuration, ifcpSessionLcFcPayloadCRCErrors=ifcpSessionLcFcPayloadCRCErrors, ifcpSessionLcStatsTable=ifcpSessionLcStatsTable, ifcpLclGtwyInstPhyIndex=ifcpLclGtwyInstPhyIndex, ifcpSessionLcStatsEntry=ifcpSessionLcStatsEntry, IfcpLTIorZero=IfcpLTIorZero, ifcpSessionLclLTIntvl=ifcpSessionLclLTIntvl, ifcpSessionLcStaleFrames=ifcpSessionLcStaleFrames, ifcpLclGatewaySessionGroup=ifcpLclGatewaySessionGroup, ifcpSessionLclNpWwun=ifcpSessionLclNpWwun, ifcpSessionHeaderCRCErrors=ifcpSessionHeaderCRCErrors, ifcpSessionLclPrtlIfIndex=ifcpSessionLclPrtlIfIndex, ifcpLclGtwyInstFcBrdcstSupport=ifcpLclGtwyInstFcBrdcstSupport, ifcpLclGatewaySessionLcStatsGroup=ifcpLclGatewaySessionLcStatsGroup, ifcpSessionStatsEntry=ifcpSessionStatsEntry, ifcpSessionLcTxFrames=ifcpSessionLcTxFrames, ifcpSessionLclPrtlAddrType=ifcpSessionLclPrtlAddrType, ifcpGroups=ifcpGroups, ifcpLclGtwyInstDescr=ifcpLclGtwyInstDescr, ifcpLclGtwyInstVersionMax=ifcpLclGtwyInstVersionMax, ifcpCompliances=ifcpCompliances, IfcpAddressMode=IfcpAddressMode, PYSNMP_MODULE_ID=ifcpMgmtMIB, ifcpLclGtwyInstAddrTransMode=ifcpLclGtwyInstAddrTransMode, ifcpLclGtwyInstIndex=ifcpLclGtwyInstIndex, IfcpIpTOVorZero=IfcpIpTOVorZero, ifcpSessionRmtNpFcid=ifcpSessionRmtNpFcid, ifcpSessionTxOctets=ifcpSessionTxOctets, ifcpSessionRxOctets=ifcpSessionRxOctets, ifcpSessionLcTxOctets=ifcpSessionLcTxOctets, ifcpSessionLcRxOctets=ifcpSessionLcRxOctets, IfcpSessionStates=IfcpSessionStates, ifcpSessionOtherErrors=ifcpSessionOtherErrors, ifcpGatewayCompliance=ifcpGatewayCompliance, ifcpSessionLcOtherErrors=ifcpSessionLcOtherErrors, ifcpSessionIpTOV=ifcpSessionIpTOV, ifcpSessionLcRxFrames=ifcpSessionLcRxFrames, ifcpSessionState=ifcpSessionState, ifcpSessionRxFrames=ifcpSessionRxFrames, ifcpSessionLcHeaderCRCErrors=ifcpSessionLcHeaderCRCErrors, ifcpSessionBound=ifcpSessionBound, ifcpSessionStorageType=ifcpSessionStorageType, ifcpSessionLclPrtlAddr=ifcpSessionLclPrtlAddr, ifcpSessionAttributesEntry=ifcpSessionAttributesEntry, ifcpGatewayObjects=ifcpGatewayObjects, ifcpSessionRmtPrtlIfAddr=ifcpSessionRmtPrtlIfAddr, ifcpLclGtwyInstDefaultLTInterval=ifcpLclGtwyInstDefaultLTInterval, ifcpSessionFcPayloadCRCErrors=ifcpSessionFcPayloadCRCErrors, ifcpLclGatewaySessionStatsGroup=ifcpLclGatewaySessionStatsGroup, ifcpLclGtwyInstTable=ifcpLclGtwyInstTable, ifcpSessionLclPrtlTcpPort=ifcpSessionLclPrtlTcpPort, ifcpSessionRmtLTIntvl=ifcpSessionRmtLTIntvl, ifcpLclGtwyInstDefaultIpTOV=ifcpLclGtwyInstDefaultIpTOV, ifcpSessionStatsTable=ifcpSessionStatsTable, ifcpSessionDiscontinuityTime=ifcpSessionDiscontinuityTime, ifcpLclGatewayInfo=ifcpLclGatewayInfo, ifcpSessionLclNpFcid=ifcpSessionLclNpFcid, ifcpSessionRmtNpWwun=ifcpSessionRmtNpWwun, ifcpMgmtMIB=ifcpMgmtMIB, ifcpGatewayConformance=ifcpGatewayConformance, ifcpLclGtwyInstNumActiveSessions=ifcpLclGtwyInstNumActiveSessions, ifcpLclGtwyInstStorageType=ifcpLclGtwyInstStorageType, ifcpSessionAttributesTable=ifcpSessionAttributesTable, ifcpSessionRmtPrtlTcpPort=ifcpSessionRmtPrtlTcpPort, ifcpSessionRmtNpFcidAlias=ifcpSessionRmtNpFcidAlias, ifcpSessionRmtPrtlIfAddrType=ifcpSessionRmtPrtlIfAddrType, ifcpSessionIndex=ifcpSessionIndex, ifcpLclGtwyInstEntry=ifcpLclGtwyInstEntry, ifcpSessionTxFrames=ifcpSessionTxFrames, ifcpLclGatewayGroup=ifcpLclGatewayGroup, ifcpLclGtwyInstVersionMin=ifcpLclGtwyInstVersionMin)



#
# PySNMP MIB module IF-CAP-STACK-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IF-CAP-STACK-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:16:17 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ValueSizeConstraint")
( ifInvStackGroup, ) = mibBuilder.importSymbols("IF-INVERTED-STACK-MIB", "ifInvStackGroup")
( ifStackGroup2, ifStackHigherLayer, ifStackLowerLayer, ) = mibBuilder.importSymbols("IF-MIB", "ifStackGroup2", "ifStackHigherLayer", "ifStackLowerLayer")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( Counter32, NotificationType, TimeTicks, IpAddress, MibScalar, MibTable, MibTableRow, MibTableColumn, ModuleIdentity, Gauge32, MibIdentifier, Unsigned32, Counter64, ObjectIdentity, mib_2, Integer32, iso, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter32", "NotificationType", "TimeTicks", "IpAddress", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "ModuleIdentity", "Gauge32", "MibIdentifier", "Unsigned32", "Counter64", "ObjectIdentity", "mib-2", "Integer32", "iso", "Bits")
( DisplayString, TextualConvention, TruthValue, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention", "TruthValue")
ifCapStackMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 166)).setRevisions(("2007-11-07 00:00",))
if mibBuilder.loadTexts: ifCapStackMIB.setLastUpdated('200711070000Z')
if mibBuilder.loadTexts: ifCapStackMIB.setOrganization('IETF Ethernet Interfaces and Hub MIB Working Group')
if mibBuilder.loadTexts: ifCapStackMIB.setContactInfo('WG charter:\n        http://www.ietf.org/html.charters/OLD/hubmib-charter.html\n\n      Mailing Lists:\n        General Discussion: hubmib@ietf.org\n\n\n\n        To Subscribe: hubmib-request@ietf.org\n        In Body: subscribe your_email_address\n\n      Chair:  Bert Wijnen\n      Postal: Alcatel-Lucent\n              Schagen 33\n              3461 GL Linschoten\n              Netherlands\n       Phone: +31-348-407-775\n       EMail: bwijnen@alcatel-lucent.com\n\n      Editor: Edward Beili\n      Postal: Actelis Networks Inc.\n              25 Bazel St., P.O.B. 10173\n              Petach-Tikva 10173\n              Israel\n       Phone: +972-3-924-3491\n       EMail: edward.beili@actelis.com')
if mibBuilder.loadTexts: ifCapStackMIB.setDescription('The objects in this MIB module are used to describe\n      cross-connect capabilities of stacked (layered) interfaces,\n      complementing ifStackTable and ifInvStackTable defined in\n      IF-MIB and IF-INVERTED-STACK-MIB, respectively.\n\n      Copyright (C) The IETF Trust (2007).  This version\n      of this MIB module is part of RFC 5066;  see the RFC\n      itself for full legal notices.')
ifCapStackObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 166, 1))
ifCapStackConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 166, 2))
ifCapStackTable = MibTable((1, 3, 6, 1, 2, 1, 166, 1, 1), )
if mibBuilder.loadTexts: ifCapStackTable.setDescription("This table, modeled after ifStackTable from IF-MIB,\n       contains information on the possible 'on-top-of'\n       relationships between the multiple sub-layers of network\n       interfaces (as opposed to actual relationships described in\n       ifStackTable).  In particular, it contains information on\n       which sub-layers MAY possibly run 'on top of' which other\n       sub-layers, as determined by cross-connect capability of the\n       device, where each sub-layer corresponds to a conceptual row\n       in the ifTable.  For example, when the sub-layer with ifIndex\n       value x can be connected to run on top of the sub-layer with\n       ifIndex value y, then this table contains:\n\n         ifCapStackStatus.x.y=true\n\n       The ifCapStackStatus.x.y row does not exist if it is\n       impossible to connect between the sub-layers x and y.\n\n       Note that for most stacked interfaces (e.g., 2BASE-TL)\n       there's always at least one higher-level interface (e.g., PCS\n       port) for each lower-level interface (e.g., PME) and at\n       least one lower-level interface for each higher-level\n       interface, that is, there is at least a single row with a\n       'true' status for any such existing value of x or y.\n\n       This table is read-only as it describes device capabilities.")
ifCapStackEntry = MibTableRow((1, 3, 6, 1, 2, 1, 166, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifStackHigherLayer"), (0, "IF-MIB", "ifStackLowerLayer"))
if mibBuilder.loadTexts: ifCapStackEntry.setDescription("Information on a particular relationship between two\n       sub-layers, specifying that one sub-layer MAY possibly run\n       on 'top' of the other sub-layer.  Each sub-layer corresponds\n       to a conceptual row in the ifTable (interface index for\n       lower and higher layer, respectively).")
ifCapStackStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 166, 1, 1, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifCapStackStatus.setDescription("The status of the 'cross-connect capability' relationship\n       between two sub-layers.  The following values can be returned:\n         true(1)         - indicates that the sub-layer interface,\n                           identified by the ifStackLowerLayer MAY\n                           be connected to run 'below' the sub-layer\n                           interface, identified by the\n                           ifStackHigherLayer index.\n         false(2)        - the sub-layer interfaces cannot be\n                           connected temporarily due to\n                           unavailability of the interface(s), e.g.,\n                           one of the interfaces is located on an\n                           absent pluggable module.\n\n       Note that lower-layer interface availability per higher-layer,\n       indicated by the value of 'true', can be constrained by\n       other parameters, for example, by the aggregation capacity of\n       a higher-layer interface or by the lower-layer interface in\n       question being already connected to another higher-layer\n       interface.  In order to ensure that a particular sub-layer can\n       be connected to another sub-layer, all respective objects\n       (e.g., ifCapStackTable, ifStackTable, and efmCuPAFCapacity for\n       EFMCu interfaces) SHALL be inspected.\n\n       This object is read-only, unlike ifStackStatus, as it\n       describes a cross-connect capability.")
ifInvCapStackTable = MibTable((1, 3, 6, 1, 2, 1, 166, 1, 2), )
if mibBuilder.loadTexts: ifInvCapStackTable.setDescription("A table containing information on the possible relationships\n       between the multiple sub-layers of network interfaces.  This\n       table, modeled after ifInvStackTable from\n       IF-INVERTED-STACK-MIB, is an inverse of the ifCapStackTable\n       defined in this MIB module.\n\n\n\n       In particular, this table contains information on which\n       sub-layers MAY run 'underneath' which other sub-layers, where\n       each sub-layer corresponds to a conceptual row in the ifTable.\n       For example, when the sub-layer with ifIndex value x MAY be\n       connected to run underneath the sub-layer with ifIndex value\n       y, then this table contains:\n\n          ifInvCapStackStatus.x.y=true\n\n       This table contains exactly the same number of rows as the\n       ifCapStackTable, but the rows appear in a different order.\n\n       This table is read-only as it describes a cross-connect\n       capability.")
ifInvCapStackEntry = MibTableRow((1, 3, 6, 1, 2, 1, 166, 1, 2, 1), ).setIndexNames((0, "IF-MIB", "ifStackLowerLayer"), (0, "IF-MIB", "ifStackHigherLayer"))
if mibBuilder.loadTexts: ifInvCapStackEntry.setDescription('Information on a particular relationship between two sub-\n        layers, specifying that one sub-layer MAY run underneath the\n        other sub-layer.  Each sub-layer corresponds to a conceptual\n        row in the ifTable.')
ifInvCapStackStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 166, 1, 2, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ifInvCapStackStatus.setDescription("The status of the possible 'cross-connect capability'\n        relationship between two sub-layers.\n\n        An instance of this object exists for each instance of the\n        ifCapStackStatus object, and vice versa.  For example, if the\n        variable ifCapStackStatus.H.L exists, then the variable\n        ifInvCapStackStatus.L.H must also exist, and vice versa.  In\n        addition, the two variables always have the same value.\n\n\n\n\n        The ifInvCapStackStatus object is read-only, as it describes\n        a cross-connect capability.")
ifCapStackGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 166, 2, 1))
ifCapStackCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 166, 2, 2))
ifCapStackGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 166, 2, 1, 1)).setObjects(*(("IF-CAP-STACK-MIB", "ifCapStackStatus"), ("IF-CAP-STACK-MIB", "ifInvCapStackStatus"),))
if mibBuilder.loadTexts: ifCapStackGroup.setDescription('A collection of objects providing information on the\n       cross-connect capability of multi-layer (stacked) network\n       interfaces.')
ifCapStackCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 166, 2, 2, 1)).setObjects(*(("IF-CAP-STACK-MIB", "ifCapStackGroup"), ("IF-MIB", "ifStackGroup2"), ("IF-INVERTED-STACK-MIB", "ifInvStackGroup"),))
if mibBuilder.loadTexts: ifCapStackCompliance.setDescription('The compliance statement for SNMP entities, which provide\n       information on the cross-connect capability of multi-layer\n       (stacked) network interfaces, with flexible cross-connect\n       between the sub-layers.')
mibBuilder.exportSymbols("IF-CAP-STACK-MIB", ifCapStackEntry=ifCapStackEntry, ifCapStackGroups=ifCapStackGroups, ifInvCapStackTable=ifInvCapStackTable, ifCapStackMIB=ifCapStackMIB, ifCapStackObjects=ifCapStackObjects, ifInvCapStackEntry=ifInvCapStackEntry, ifCapStackGroup=ifCapStackGroup, ifCapStackTable=ifCapStackTable, ifCapStackStatus=ifCapStackStatus, ifInvCapStackStatus=ifInvCapStackStatus, ifCapStackCompliances=ifCapStackCompliances, PYSNMP_MODULE_ID=ifCapStackMIB, ifCapStackCompliance=ifCapStackCompliance, ifCapStackConformance=ifCapStackConformance)



#
# PySNMP MIB module DISMAN-SCHEDULE-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DISMAN-SCHEDULE-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:08:12 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ValueSizeConstraint, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ValueSizeConstraint", "ValueRangeConstraint", "ConstraintsIntersection")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( TimeTicks, Gauge32, Unsigned32, mib_2, MibIdentifier, zeroDotZero, iso, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, NotificationType, Counter32, Counter64, Integer32, ObjectIdentity, ModuleIdentity, IpAddress, ) = mibBuilder.importSymbols("SNMPv2-SMI", "TimeTicks", "Gauge32", "Unsigned32", "mib-2", "MibIdentifier", "zeroDotZero", "iso", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "NotificationType", "Counter32", "Counter64", "Integer32", "ObjectIdentity", "ModuleIdentity", "IpAddress")
( DisplayString, RowStatus, DateAndTime, StorageType, TextualConvention, VariablePointer, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "RowStatus", "DateAndTime", "StorageType", "TextualConvention", "VariablePointer")
schedMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 63)).setRevisions(("2002-01-07 00:00", "1998-11-17 18:00",))
if mibBuilder.loadTexts: schedMIB.setLastUpdated('200201070000Z')
if mibBuilder.loadTexts: schedMIB.setOrganization('IETF Distributed Management Working Group')
if mibBuilder.loadTexts: schedMIB.setContactInfo('WG EMail:  disman@dorothy.bmc.com\n         Subscribe: disman-request@dorothy.bmc.com\n\n         Chair:     Randy Presuhn\n                    BMC Software, Inc.\n         Postal:    Office 1-3141\n                    2141 North First Street\n                    San Jose,  California 95131\n                    USA\n         EMail:     rpresuhn@bmc.com\n         Phone:     +1 408 546-1006\n\n         Editor:    David B. Levi\n                    Nortel Networks\n         Postal:    4401 Great America Parkway\n                    Santa Clara, CA 95052-8185\n                    USA\n         EMail:     dlevi@nortelnetworks.com\n         Phone:     +1 865 686 0432\n\n\n         Editor:    Juergen Schoenwaelder\n                    TU Braunschweig\n         Postal:    Bueltenweg 74/75\n                    38106 Braunschweig\n                    Germany\n         EMail:     schoenw@ibr.cs.tu-bs.de\n         Phone:     +49 531 391-3283')
if mibBuilder.loadTexts: schedMIB.setDescription('This MIB module defines a MIB which provides mechanisms to\n         schedule SNMP set operations periodically or at specific\n         points in time.')
schedObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 63, 1))
schedNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 63, 2))
schedConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 63, 3))
class SnmpPduErrorStatus(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(-1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,))
    namedValues = NamedValues(("noResponse", -1), ("noError", 0), ("tooBig", 1), ("noSuchName", 2), ("badValue", 3), ("readOnly", 4), ("genErr", 5), ("noAccess", 6), ("wrongType", 7), ("wrongLength", 8), ("wrongEncoding", 9), ("wrongValue", 10), ("noCreation", 11), ("inconsistentValue", 12), ("resourceUnavailable", 13), ("commitFailed", 14), ("undoFailed", 15), ("authorizationError", 16), ("notWritable", 17), ("inconsistentName", 18),)

schedLocalTime = MibScalar((1, 3, 6, 1, 2, 1, 63, 1, 1), DateAndTime().subtype(subtypeSpec=ValueSizeConstraint(11,11)).setFixedLength(11)).setMaxAccess("readonly")
if mibBuilder.loadTexts: schedLocalTime.setDescription('The local time used by the scheduler.  Schedules which\n         refer to calendar time will use the local time indicated\n         by this object.  An implementation MUST return all 11 bytes\n         of the DateAndTime textual-convention so that a manager\n         may retrieve the offset from GMT time.')
schedTable = MibTable((1, 3, 6, 1, 2, 1, 63, 1, 2), )
if mibBuilder.loadTexts: schedTable.setDescription('This table defines scheduled actions triggered by\n         SNMP set operations.')
schedEntry = MibTableRow((1, 3, 6, 1, 2, 1, 63, 1, 2, 1), ).setIndexNames((0, "DISMAN-SCHEDULE-MIB", "schedOwner"), (0, "DISMAN-SCHEDULE-MIB", "schedName"))
if mibBuilder.loadTexts: schedEntry.setDescription('An entry describing a particular scheduled action.\n\n         Unless noted otherwise, writable objects of this row\n         can be modified independent of the current value of\n         schedRowStatus, schedAdminStatus and schedOperStatus.\n         In particular, it is legal to modify schedInterval\n         and the objects in the schedCalendarGroup when\n         schedRowStatus is active and schedAdminStatus and\n         schedOperStatus are both enabled.')
schedOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 1), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)))
if mibBuilder.loadTexts: schedOwner.setDescription('The owner of this scheduling entry.  The exact semantics of\n         this string are subject to the security policy defined by\n\n         the security administrator.')
schedName = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 2), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,32)))
if mibBuilder.loadTexts: schedName.setDescription('The locally-unique, administratively assigned name for this\n         scheduling entry.  This object allows a schedOwner to have\n         multiple entries in the schedTable.')
schedDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 3), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedDescr.setDescription('The human readable description of the purpose of this\n         scheduling entry.')
schedInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 4), Unsigned32()).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedInterval.setDescription('The number of seconds between two action invocations of\n         a periodic scheduler.  Implementations must guarantee\n         that action invocations will not occur before at least\n         schedInterval seconds have passed.\n\n         The scheduler must ignore all periodic schedules that\n         have a schedInterval value of 0.  A periodic schedule\n         with a scheduling interval of 0 seconds will therefore\n         never invoke an action.\n\n         Implementations may be forced to delay invocations in the\n         face of local constraints.  A scheduled management function\n         should therefore not rely on the accuracy provided by the\n         scheduler implementation.\n\n         Note that implementations which maintain a list of pending\n         activations must re-calculate them when this object is\n         changed.')
schedWeekDay = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 5), Bits().clone(namedValues=NamedValues(("sunday", 0), ("monday", 1), ("tuesday", 2), ("wednesday", 3), ("thursday", 4), ("friday", 5), ("saturday", 6),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedWeekDay.setDescription('The set of weekdays on which the scheduled action should\n         take place.  Setting multiple bits will include several\n         weekdays in the set of possible weekdays for this schedule.\n         Setting all bits will cause the scheduler to ignore the\n         weekday.\n\n         Note that implementations which maintain a list of pending\n         activations must re-calculate them when this object is\n         changed.')
schedMonth = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 6), Bits().clone(namedValues=NamedValues(("january", 0), ("february", 1), ("march", 2), ("april", 3), ("may", 4), ("june", 5), ("july", 6), ("august", 7), ("september", 8), ("october", 9), ("november", 10), ("december", 11),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedMonth.setDescription('The set of months during which the scheduled action should\n         take place.  Setting multiple bits will include several\n         months in the set of possible months for this schedule.\n\n         Setting all bits will cause the scheduler to ignore the\n         month.\n\n         Note that implementations which maintain a list of pending\n         activations must re-calculate them when this object is\n         changed.')
schedDay = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 7), Bits().clone(namedValues=NamedValues(("d1", 0), ("d2", 1), ("d3", 2), ("d4", 3), ("d5", 4), ("d6", 5), ("d7", 6), ("d8", 7), ("d9", 8), ("d10", 9), ("d11", 10), ("d12", 11), ("d13", 12), ("d14", 13), ("d15", 14), ("d16", 15), ("d17", 16), ("d18", 17), ("d19", 18), ("d20", 19), ("d21", 20), ("d22", 21), ("d23", 22), ("d24", 23), ("d25", 24), ("d26", 25), ("d27", 26), ("d28", 27), ("d29", 28), ("d30", 29), ("d31", 30), ("r1", 31), ("r2", 32), ("r3", 33), ("r4", 34), ("r5", 35), ("r6", 36), ("r7", 37), ("r8", 38), ("r9", 39), ("r10", 40), ("r11", 41), ("r12", 42), ("r13", 43), ("r14", 44), ("r15", 45), ("r16", 46), ("r17", 47), ("r18", 48), ("r19", 49), ("r20", 50), ("r21", 51), ("r22", 52), ("r23", 53), ("r24", 54), ("r25", 55), ("r26", 56), ("r27", 57), ("r28", 58), ("r29", 59), ("r30", 60), ("r31", 61),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedDay.setDescription("The set of days in a month on which a scheduled action\n         should take place.  There are two sets of bits one can\n         use to define the day within a month:\n\n         Enumerations starting with the letter 'd' indicate a\n         day in a month relative to the first day of a month.\n         The first day of the month can therefore be specified\n         by setting the bit d1(0) and d31(30) means the last\n         day of a month with 31 days.\n\n         Enumerations starting with the letter 'r' indicate a\n         day in a month in reverse order, relative to the last\n         day of a month.  The last day in the month can therefore\n         be specified by setting the bit r1(31) and r31(61) means\n         the first day of a month with 31 days.\n\n         Setting multiple bits will include several days in the set\n         of possible days for this schedule.  Setting all bits will\n         cause the scheduler to ignore the day within a month.\n\n         Setting all bits starting with the letter 'd' or the\n         letter 'r' will also cause the scheduler to ignore the\n         day within a month.\n\n         Note that implementations which maintain a list of pending\n         activations must re-calculate them when this object is\n         changed.")
schedHour = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 8), Bits().clone(namedValues=NamedValues(("h0", 0), ("h1", 1), ("h2", 2), ("h3", 3), ("h4", 4), ("h5", 5), ("h6", 6), ("h7", 7), ("h8", 8), ("h9", 9), ("h10", 10), ("h11", 11), ("h12", 12), ("h13", 13), ("h14", 14), ("h15", 15), ("h16", 16), ("h17", 17), ("h18", 18), ("h19", 19), ("h20", 20), ("h21", 21), ("h22", 22), ("h23", 23),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedHour.setDescription('The set of hours within a day during which the scheduled\n         action should take place.\n\n         Note that implementations which maintain a list of pending\n         activations must re-calculate them when this object is\n         changed.')
schedMinute = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 9), Bits().clone(namedValues=NamedValues(("m0", 0), ("m1", 1), ("m2", 2), ("m3", 3), ("m4", 4), ("m5", 5), ("m6", 6), ("m7", 7), ("m8", 8), ("m9", 9), ("m10", 10), ("m11", 11), ("m12", 12), ("m13", 13), ("m14", 14), ("m15", 15), ("m16", 16), ("m17", 17), ("m18", 18), ("m19", 19), ("m20", 20), ("m21", 21), ("m22", 22), ("m23", 23), ("m24", 24), ("m25", 25), ("m26", 26), ("m27", 27), ("m28", 28), ("m29", 29), ("m30", 30), ("m31", 31), ("m32", 32), ("m33", 33), ("m34", 34), ("m35", 35), ("m36", 36), ("m37", 37), ("m38", 38), ("m39", 39), ("m40", 40), ("m41", 41), ("m42", 42), ("m43", 43), ("m44", 44), ("m45", 45), ("m46", 46), ("m47", 47), ("m48", 48), ("m49", 49), ("m50", 50), ("m51", 51), ("m52", 52), ("m53", 53), ("m54", 54), ("m55", 55), ("m56", 56), ("m57", 57), ("m58", 58), ("m59", 59),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedMinute.setDescription('The set of minutes within an hour when the scheduled action\n         should take place.\n\n         Note that implementations which maintain a list of pending\n         activations must re-calculate them when this object is\n         changed.')
schedContextName = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 10), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedContextName.setDescription('The context which contains the local MIB variable pointed\n         to by schedVariable.')
schedVariable = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 11), VariablePointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedVariable.setDescription('An object identifier pointing to a local MIB variable\n         which resolves to an ASN.1 primitive type of INTEGER.')
schedValue = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 12), Integer32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedValue.setDescription('The value which is written to the MIB object pointed to by\n         schedVariable when the scheduler invokes an action.  The\n         implementation shall enforce the use of access control\n         rules when performing the set operation on schedVariable.\n         This is accomplished by calling the isAccessAllowed abstract\n         service interface as defined in RFC 2571.\n\n         Note that an implementation may choose to issue an SNMP Set\n         message to the SNMP engine and leave the access control\n         decision to the normal message processing procedure.')
schedType = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 13), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("periodic", 1), ("calendar", 2), ("oneshot", 3),)).clone('periodic')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedType.setDescription("The type of this schedule.  The value periodic(1) indicates\n         that this entry specifies a periodic schedule.  A periodic\n         schedule is defined by the value of schedInterval.  The\n         values of schedWeekDay, schedMonth, schedDay, schedHour\n         and schedMinute are ignored.\n\n         The value calendar(2) indicates that this entry describes a\n         calendar schedule.  A calendar schedule is defined by the\n         values of schedWeekDay, schedMonth, schedDay, schedHour and\n         schedMinute.  The value of schedInterval is ignored.  A\n         calendar schedule will trigger on all local times that\n         satisfy the bits set in schedWeekDay, schedMonth, schedDay,\n         schedHour and schedMinute.\n\n         The value oneshot(3) indicates that this entry describes a\n         one-shot schedule.  A one-shot schedule is similar to a\n         calendar schedule with the additional feature that it\n         disables itself by changing in the `finished'\n         schedOperStatus once the schedule triggers an action.\n\n         Note that implementations which maintain a list of pending\n         activations must re-calculate them when this object is\n         changed.")
schedAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 14), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2),)).clone('disabled')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedAdminStatus.setDescription('The desired state of the schedule.')
schedOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 15), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2), ("finished", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: schedOperStatus.setDescription('The current operational state of this schedule.  The state\n         enabled(1) indicates this entry is active and that the\n         scheduler will invoke actions at appropriate times.  The\n         disabled(2) state indicates that this entry is currently\n         inactive and ignored by the scheduler.  The finished(3)\n         state indicates that the schedule has ended.  Schedules\n         in the finished(3) state are ignored by the scheduler.\n         A one-shot schedule enters the finished(3) state when it\n         deactivates itself.\n\n         Note that the operational state must not be enabled(1)\n         when the schedRowStatus is not active.')
schedFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: schedFailures.setDescription('This variable counts the number of failures while invoking\n         the scheduled action.  This counter at most increments once\n         for a triggered action.')
schedLastFailure = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 17), SnmpPduErrorStatus().clone('noError')).setMaxAccess("readonly")
if mibBuilder.loadTexts: schedLastFailure.setDescription('The most recent error that occurred during the invocation of\n         a scheduled action.  The value noError(0) is returned\n         if no errors have occurred yet.')
schedLastFailed = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 18), DateAndTime().clone(hexValue="0000000000000000")).setMaxAccess("readonly")
if mibBuilder.loadTexts: schedLastFailed.setDescription("The date and time when the most recent failure occurred.\n\n         The value '0000000000000000'H is returned if no failure\n         occurred since the last re-initialization of the scheduler.")
schedStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 19), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedStorageType.setDescription("This object defines whether this scheduled action is kept\n         in volatile storage and lost upon reboot or if this row is\n         backed up by non-volatile or permanent storage.\n\n         Conceptual rows having the value `permanent' must allow\n         write access to the columnar objects schedDescr,\n         schedInterval, schedContextName, schedVariable, schedValue,\n         and schedAdminStatus.  If an implementation supports the\n         schedCalendarGroup, write access must be also allowed to\n         the columnar objects schedWeekDay, schedMonth, schedDay,\n         schedHour, schedMinute.")
schedRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 20), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: schedRowStatus.setDescription('The status of this scheduled action.  A control that allows\n         entries to be added and removed from this table.\n\n         Note that the operational state must change to enabled\n         when the administrative state is enabled and the row\n         status changes to active(1).\n\n         Attempts to destroy(6) a row or to set a row\n         notInService(2) while the operational state is enabled\n         result in inconsistentValue errors.\n\n         The value of this object has no effect on whether other\n         objects in this conceptual row can be modified.')
schedTriggers = MibTableColumn((1, 3, 6, 1, 2, 1, 63, 1, 2, 1, 21), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: schedTriggers.setDescription('This variable counts the number of attempts (either\n         successful or failed) to invoke the scheduled action.')
schedTraps = MibIdentifier((1, 3, 6, 1, 2, 1, 63, 2, 0))
schedActionFailure = NotificationType((1, 3, 6, 1, 2, 1, 63, 2, 0, 1)).setObjects(*(("DISMAN-SCHEDULE-MIB", "schedLastFailure"), ("DISMAN-SCHEDULE-MIB", "schedLastFailed"),))
if mibBuilder.loadTexts: schedActionFailure.setDescription('This notification is generated whenever the invocation of a\n         scheduled action fails.')
schedCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 63, 3, 1))
schedGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 63, 3, 2))
schedCompliance2 = ModuleCompliance((1, 3, 6, 1, 2, 1, 63, 3, 1, 2)).setObjects(*(("DISMAN-SCHEDULE-MIB", "schedGroup2"), ("DISMAN-SCHEDULE-MIB", "schedNotificationsGroup"), ("DISMAN-SCHEDULE-MIB", "schedCalendarGroup"),))
if mibBuilder.loadTexts: schedCompliance2.setDescription('The compliance statement for SNMP entities which implement\n         the scheduling MIB.')
schedGroup2 = ObjectGroup((1, 3, 6, 1, 2, 1, 63, 3, 2, 4)).setObjects(*(("DISMAN-SCHEDULE-MIB", "schedDescr"), ("DISMAN-SCHEDULE-MIB", "schedInterval"), ("DISMAN-SCHEDULE-MIB", "schedContextName"), ("DISMAN-SCHEDULE-MIB", "schedVariable"), ("DISMAN-SCHEDULE-MIB", "schedValue"), ("DISMAN-SCHEDULE-MIB", "schedType"), ("DISMAN-SCHEDULE-MIB", "schedAdminStatus"), ("DISMAN-SCHEDULE-MIB", "schedOperStatus"), ("DISMAN-SCHEDULE-MIB", "schedFailures"), ("DISMAN-SCHEDULE-MIB", "schedLastFailure"), ("DISMAN-SCHEDULE-MIB", "schedLastFailed"), ("DISMAN-SCHEDULE-MIB", "schedStorageType"), ("DISMAN-SCHEDULE-MIB", "schedRowStatus"), ("DISMAN-SCHEDULE-MIB", "schedTriggers"),))
if mibBuilder.loadTexts: schedGroup2.setDescription('A collection of objects providing scheduling capabilities.')
schedCalendarGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 63, 3, 2, 2)).setObjects(*(("DISMAN-SCHEDULE-MIB", "schedLocalTime"), ("DISMAN-SCHEDULE-MIB", "schedWeekDay"), ("DISMAN-SCHEDULE-MIB", "schedMonth"), ("DISMAN-SCHEDULE-MIB", "schedDay"), ("DISMAN-SCHEDULE-MIB", "schedHour"), ("DISMAN-SCHEDULE-MIB", "schedMinute"),))
if mibBuilder.loadTexts: schedCalendarGroup.setDescription('A collection of objects providing calendar based schedules.')
schedNotificationsGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 63, 3, 2, 3)).setObjects(*(("DISMAN-SCHEDULE-MIB", "schedActionFailure"),))
if mibBuilder.loadTexts: schedNotificationsGroup.setDescription('The notifications emitted by the scheduler.')
schedCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 63, 3, 1, 1)).setObjects(*(("DISMAN-SCHEDULE-MIB", "schedGroup"), ("DISMAN-SCHEDULE-MIB", "schedNotificationsGroup"), ("DISMAN-SCHEDULE-MIB", "schedCalendarGroup"),))
if mibBuilder.loadTexts: schedCompliance.setDescription('The compliance statement for SNMP entities which implement\n         the scheduling MIB.')
schedGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 63, 3, 2, 1)).setObjects(*(("DISMAN-SCHEDULE-MIB", "schedDescr"), ("DISMAN-SCHEDULE-MIB", "schedInterval"), ("DISMAN-SCHEDULE-MIB", "schedContextName"), ("DISMAN-SCHEDULE-MIB", "schedVariable"), ("DISMAN-SCHEDULE-MIB", "schedValue"), ("DISMAN-SCHEDULE-MIB", "schedType"), ("DISMAN-SCHEDULE-MIB", "schedAdminStatus"), ("DISMAN-SCHEDULE-MIB", "schedOperStatus"), ("DISMAN-SCHEDULE-MIB", "schedFailures"), ("DISMAN-SCHEDULE-MIB", "schedLastFailure"), ("DISMAN-SCHEDULE-MIB", "schedLastFailed"), ("DISMAN-SCHEDULE-MIB", "schedStorageType"), ("DISMAN-SCHEDULE-MIB", "schedRowStatus"),))
if mibBuilder.loadTexts: schedGroup.setDescription('A collection of objects providing scheduling capabilities.')
mibBuilder.exportSymbols("DISMAN-SCHEDULE-MIB", schedGroup=schedGroup, schedVariable=schedVariable, schedGroup2=schedGroup2, schedGroups=schedGroups, schedCompliance2=schedCompliance2, schedTraps=schedTraps, schedHour=schedHour, SnmpPduErrorStatus=SnmpPduErrorStatus, schedWeekDay=schedWeekDay, schedLastFailed=schedLastFailed, schedContextName=schedContextName, schedValue=schedValue, schedFailures=schedFailures, PYSNMP_MODULE_ID=schedMIB, schedObjects=schedObjects, schedMinute=schedMinute, schedDay=schedDay, schedName=schedName, schedMIB=schedMIB, schedType=schedType, schedTriggers=schedTriggers, schedDescr=schedDescr, schedOperStatus=schedOperStatus, schedAdminStatus=schedAdminStatus, schedNotifications=schedNotifications, schedStorageType=schedStorageType, schedRowStatus=schedRowStatus, schedOwner=schedOwner, schedConformance=schedConformance, schedLocalTime=schedLocalTime, schedCompliances=schedCompliances, schedCompliance=schedCompliance, schedLastFailure=schedLastFailure, schedNotificationsGroup=schedNotificationsGroup, schedCalendarGroup=schedCalendarGroup, schedTable=schedTable, schedEntry=schedEntry, schedMonth=schedMonth, schedActionFailure=schedActionFailure, schedInterval=schedInterval)



#
# PySNMP MIB module IANA-ITU-ALARM-TC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IANA-ITU-ALARM-TC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:15:53 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion, ValueSizeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ValueSizeConstraint", "ConstraintsIntersection")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( IpAddress, Integer32, Gauge32, mib_2, TimeTicks, NotificationType, ModuleIdentity, Counter32, Bits, ObjectIdentity, Unsigned32, MibIdentifier, Counter64, iso, MibScalar, MibTable, MibTableRow, MibTableColumn, ) = mibBuilder.importSymbols("SNMPv2-SMI", "IpAddress", "Integer32", "Gauge32", "mib-2", "TimeTicks", "NotificationType", "ModuleIdentity", "Counter32", "Bits", "ObjectIdentity", "Unsigned32", "MibIdentifier", "Counter64", "iso", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
ianaItuAlarmNumbers = ModuleIdentity((1, 3, 6, 1, 2, 1, 119)).setRevisions(("2004-09-09 00:00",))
if mibBuilder.loadTexts: ianaItuAlarmNumbers.setLastUpdated('200409090000Z')
if mibBuilder.loadTexts: ianaItuAlarmNumbers.setOrganization('IANA')
if mibBuilder.loadTexts: ianaItuAlarmNumbers.setContactInfo('Postal:    Internet Assigned Numbers Authority\n                     Internet Corporation for Assigned Names\n                     and Numbers\n                     4676 Admiralty Way, Suite 330\n                     Marina del Rey, CA 90292-6601\n                     USA\n\n         Tel:    +1  310-823-9358\n         E-Mail: iana@iana.org')
if mibBuilder.loadTexts: ianaItuAlarmNumbers.setDescription('The MIB module defines the ITU Alarm\n         textual convention for objects expected to require\n         regular extension.\n\n         Copyright (C) The Internet Society (2004).  The\n         initial version of this MIB module was published\n         in RFC 3877.  For full legal notices see the RFC\n         itself.  Supplementary information may be available on:\n         http://www.ietf.org/copyrights/ianamib.html')
class IANAItuProbableCause(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 201, 202, 203, 204, 205, 206, 207, 500, 501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 540, 541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552, 553, 554, 555, 600, 601, 602, 603, 604, 605, 606, 607, 608, 609, 610, 611, 612, 613, 614, 615, 1024,))
    namedValues = NamedValues(("aIS", 1), ("callSetUpFailure", 2), ("degradedSignal", 3), ("farEndReceiverFailure", 4), ("framingError", 5), ("lossOfFrame", 6), ("lossOfPointer", 7), ("lossOfSignal", 8), ("payloadTypeMismatch", 9), ("transmissionError", 10), ("remoteAlarmInterface", 11), ("excessiveBER", 12), ("pathTraceMismatch", 13), ("unavailable", 14), ("signalLabelMismatch", 15), ("lossOfMultiFrame", 16), ("receiveFailure", 17), ("transmitFailure", 18), ("modulationFailure", 19), ("demodulationFailure", 20), ("broadcastChannelFailure", 21), ("connectionEstablishmentError", 22), ("invalidMessageReceived", 23), ("localNodeTransmissionError", 24), ("remoteNodeTransmissionError", 25), ("routingFailure", 26), ("backplaneFailure", 51), ("dataSetProblem", 52), ("equipmentIdentifierDuplication", 53), ("externalIFDeviceProblem", 54), ("lineCardProblem", 55), ("multiplexerProblem", 56), ("nEIdentifierDuplication", 57), ("powerProblem", 58), ("processorProblem", 59), ("protectionPathFailure", 60), ("receiverFailure", 61), ("replaceableUnitMissing", 62), ("replaceableUnitTypeMismatch", 63), ("synchronizationSourceMismatch", 64), ("terminalProblem", 65), ("timingProblem", 66), ("transmitterFailure", 67), ("trunkCardProblem", 68), ("replaceableUnitProblem", 69), ("realTimeClockFailure", 70), ("antennaFailure", 71), ("batteryChargingFailure", 72), ("diskFailure", 73), ("frequencyHoppingFailure", 74), ("iODeviceError", 75), ("lossOfSynchronisation", 76), ("lossOfRedundancy", 77), ("powerSupplyFailure", 78), ("signalQualityEvaluationFailure", 79), ("tranceiverFailure", 80), ("protectionMechanismFailure", 81), ("protectingResourceFailure", 82), ("airCompressorFailure", 101), ("airConditioningFailure", 102), ("airDryerFailure", 103), ("batteryDischarging", 104), ("batteryFailure", 105), ("commercialPowerFailure", 106), ("coolingFanFailure", 107), ("engineFailure", 108), ("fireDetectorFailure", 109), ("fuseFailure", 110), ("generatorFailure", 111), ("lowBatteryThreshold", 112), ("pumpFailure", 113), ("rectifierFailure", 114), ("rectifierHighVoltage", 115), ("rectifierLowFVoltage", 116), ("ventilationsSystemFailure", 117), ("enclosureDoorOpen", 118), ("explosiveGas", 119), ("fire", 120), ("flood", 121), ("highHumidity", 122), ("highTemperature", 123), ("highWind", 124), ("iceBuildUp", 125), ("intrusionDetection", 126), ("lowFuel", 127), ("lowHumidity", 128), ("lowCablePressure", 129), ("lowTemperatue", 130), ("lowWater", 131), ("smoke", 132), ("toxicGas", 133), ("coolingSystemFailure", 134), ("externalEquipmentFailure", 135), ("externalPointFailure", 136), ("storageCapacityProblem", 151), ("memoryMismatch", 152), ("corruptData", 153), ("outOfCPUCycles", 154), ("sfwrEnvironmentProblem", 155), ("sfwrDownloadFailure", 156), ("lossOfRealTimel", 157), ("applicationSubsystemFailure", 158), ("configurationOrCustomisationError", 159), ("databaseInconsistency", 160), ("fileError", 161), ("outOfMemory", 162), ("softwareError", 163), ("timeoutExpired", 164), ("underlayingResourceUnavailable", 165), ("versionMismatch", 166), ("bandwidthReduced", 201), ("congestion", 202), ("excessiveErrorRate", 203), ("excessiveResponseTime", 204), ("excessiveRetransmissionRate", 205), ("reducedLoggingCapability", 206), ("systemResourcesOverload", 207), ("adapterError", 500), ("applicationSubsystemFailture", 501), ("bandwidthReducedX733", 502), ("callEstablishmentError", 503), ("communicationsProtocolError", 504), ("communicationsSubsystemFailure", 505), ("configurationOrCustomizationError", 506), ("congestionX733", 507), ("coruptData", 508), ("cpuCyclesLimitExceeded", 509), ("dataSetOrModemError", 510), ("degradedSignalX733", 511), ("dteDceInterfaceError", 512), ("enclosureDoorOpenX733", 513), ("equipmentMalfunction", 514), ("excessiveVibration", 515), ("fileErrorX733", 516), ("fireDetected", 517), ("framingErrorX733", 518), ("heatingVentCoolingSystemProblem", 519), ("humidityUnacceptable", 520), ("inputOutputDeviceError", 521), ("inputDeviceError", 522), ("lanError", 523), ("leakDetected", 524), ("localNodeTransmissionErrorX733", 525), ("lossOfFrameX733", 526), ("lossOfSignalX733", 527), ("materialSupplyExhausted", 528), ("multiplexerProblemX733", 529), ("outOfMemoryX733", 530), ("ouputDeviceError", 531), ("performanceDegraded", 532), ("powerProblems", 533), ("pressureUnacceptable", 534), ("processorProblems", 535), ("pumpFailureX733", 536), ("queueSizeExceeded", 537), ("receiveFailureX733", 538), ("receiverFailureX733", 539), ("remoteNodeTransmissionErrorX733", 540), ("resourceAtOrNearingCapacity", 541), ("responseTimeExecessive", 542), ("retransmissionRateExcessive", 543), ("softwareErrorX733", 544), ("softwareProgramAbnormallyTerminated", 545), ("softwareProgramError", 546), ("storageCapacityProblemX733", 547), ("temperatureUnacceptable", 548), ("thresholdCrossed", 549), ("timingProblemX733", 550), ("toxicLeakDetected", 551), ("transmitFailureX733", 552), ("transmiterFailure", 553), ("underlyingResourceUnavailable", 554), ("versionMismatchX733", 555), ("authenticationFailure", 600), ("breachOfConfidentiality", 601), ("cableTamper", 602), ("delayedInformation", 603), ("denialOfService", 604), ("duplicateInformation", 605), ("informationMissing", 606), ("informationModificationDetected", 607), ("informationOutOfSequence", 608), ("keyExpired", 609), ("nonRepudiationFailure", 610), ("outOfHoursActivity", 611), ("outOfService", 612), ("proceduralError", 613), ("unauthorizedAccessAttempt", 614), ("unexpectedInformation", 615), ("other", 1024),)

class IANAItuEventType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11,))
    namedValues = NamedValues(("other", 1), ("communicationsAlarm", 2), ("qualityOfServiceAlarm", 3), ("processingErrorAlarm", 4), ("equipmentAlarm", 5), ("environmentalAlarm", 6), ("integrityViolation", 7), ("operationalViolation", 8), ("physicalViolation", 9), ("securityServiceOrMechanismViolation", 10), ("timeDomainViolation", 11),)

mibBuilder.exportSymbols("IANA-ITU-ALARM-TC-MIB", IANAItuProbableCause=IANAItuProbableCause, ianaItuAlarmNumbers=ianaItuAlarmNumbers, PYSNMP_MODULE_ID=ianaItuAlarmNumbers, IANAItuEventType=IANAItuEventType)
